@@ -52,7 +52,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN_IPS'				=> 'Porttikielto IP:n mukaan',
 	'ACP_BAN_USERNAMES'			=> 'Porttikielto käyttäjätunnusten mukaan ',
 	'ACP_BBCODES'				=> 'BBCode',
-	'ACP_BOARD_CONFIGURATION'	=> 'keskustelufoorumin asetukset',
+	'ACP_BOARD_CONFIGURATION'	=> 'Keskustelufoorumin asetukset',
 	'ACP_BOARD_FEATURES'		=> 'Yleiset toiminnot',
 	'ACP_BOARD_MANAGEMENT'		=> 'Hallinta',
 	'ACP_BOARD_SETTINGS'		=> 'Yleiset asetukset',
@@ -135,7 +135,7 @@ $lang = array_merge($lang, array(
 	'ACP_PERMISSION_MASKS'		=> 'Oikeuksien maskit',
 	'ACP_PERMISSION_ROLES'		=> 'Oikeuksien roolit',
 	'ACP_PERMISSION_TRACE'		=> 'Oikeuksien jäljitys',
-	'ACP_PHP_INFO'				=> 'PHP-Informaatio',
+	'ACP_PHP_INFO'				=> 'PHP:n tiedot',
 	'ACP_POST_SETTINGS'			=> 'Viestien lähetyksen asetukset',
 	'ACP_PRUNE_FORUMS'			=> 'Automaattinen siivous',
 	'ACP_PRUNE_USERS'			=> 'Käyttäjien siivoaminen',
@@ -149,7 +149,7 @@ $lang = array_merge($lang, array(
 
 	'ACP_RESTORE'				=> 'Palauta',
 	'ACP_FEED'					=> 'Syötteiden hallinta',
-	'ACP_FEED_SETTINGS'			=> 'syötteiden asetukset',
+	'ACP_FEED_SETTINGS'			=> 'Syötteiden asetukset',
 
 
 	'ACP_SEARCH'				=> 'Hakutoiminnon asetukset',
@@ -191,8 +191,8 @@ $lang = array_merge($lang, array(
 	'ACP_USER_WARNINGS'				=> 'Varoitukset',
 
 	'ACP_VC_SETTINGS'					=> 'Roskapostituksen esto',
-	'ACP_VC_CAPTCHA_DISPLAY'			=> 'CAPTCHA Kuvan esikatselu',
-	'ACP_VERSION_CHECK'					=> 'Tarkista onko päivityksiä',
+	'ACP_VC_CAPTCHA_DISPLAY'			=> 'CAPTCHA-kuvan esikatselu',
+	'ACP_VERSION_CHECK'					=> 'Tarkista päivitysten saatavuus',
 	'ACP_VIEW_ADMIN_PERMISSIONS'		=> 'Katso ylläpitäjän oikeuksia',
 	'ACP_VIEW_FORUM_MOD_PERMISSIONS'	=> 'Katso alueen valvojien oikeuksia',
 	'ACP_VIEW_FORUM_PERMISSIONS'		=> 'Katso alueen oikeuksia',
@@ -225,7 +225,7 @@ $lang = array_merge($lang, array(
 	'DOWNLOAD'					=> 'Lataa koneellesi',
 	'DOWNLOAD_AS'				=> 'Lataa muodossa',
 	'DOWNLOAD_STORE'			=> 'Lataa tai tallenna tiedosto',
-	'DOWNLOAD_STORE_EXPLAIN'	=> 'Voit ladata tiedoston tai tallentaa sen  <samp>store/</samp> -hakemistoon.',
+	'DOWNLOAD_STORE_EXPLAIN'	=> 'Voit ladata tiedoston tai tallentaa sen <samp>store/</samp>-hakemistoon.',
 
 	'EDIT'					=> 'Muokkaa',
 	'ENABLE'				=> 'Ota käyttöön',
@@ -245,9 +245,9 @@ $lang = array_merge($lang, array(
 	'LOGIN_ADMIN_CONFIRM'	=> 'Kirjaudu sisään uudelleen hallinnoidaksesi keskustelufoorumia.',
 	'LOGIN_ADMIN_SUCCESS'	=> 'Olet tunnistettu ylläpitäjäksi. Pääset hetken kuluttua ylläpitoon.',
 	'LOOK_UP_FORUM'			=> 'Valitse keskustelualue',
-	'LOOK_UP_FORUMS_EXPLAIN'=> 'Voit valita useamman, kuin yhden alueen',
+	'LOOK_UP_FORUMS_EXPLAIN'=> 'Voit valita useamman kuin yhden alueen',
 
-	'MANAGE'				=> 'hallitse',
+	'MANAGE'				=> 'Hallitse',
 	'MENU_TOGGLE'			=> 'Näytä tai piilota sivupaneeli',
 	'MORE'					=> 'Lisää',			// Not used at the moment
 	'MORE_INFORMATION'		=> 'Lisätietoja »',
@@ -259,8 +259,8 @@ $lang = array_merge($lang, array(
 	'NO_EMAILS_DEFINED'		=> 'Sopivaa sähköpostiosoitetta ei löytynyt',
 	'NO_PASSWORD_SUPPLIED'	=> 'Anna salasanasi, ennen kuin jatkat ylläpidon asetuksiin.',	
 
-	'OFF'					=> 'Off',
-	'ON'					=> 'On',
+	'OFF'					=> 'Pois käytöstä',
+	'ON'					=> 'Käytössä',
 
 	'PARSE_BBCODE'						=> 'Käsittele BBCode',
 	'PARSE_SMILIES'						=> 'Käsittele hymiöt',
@@ -276,8 +276,8 @@ $lang = array_merge($lang, array(
 	'SELECT_ANONYMOUS'		=> 'Valitse vierailijan tunnus',
 	'SELECT_OPTION'			=> 'Valitse vaihtoehto',
 
-	'SETTING_TOO_LOW'		=> 'Antamasi arvo asetukselle “%1$s” on liian pieni. Minimi arvo on %2$d.',
-	'SETTING_TOO_BIG'		=> 'Antamasi arvo asetukselle “%1$s” on liian suuri. Maksimi arvo on %2$d.',	
+	'SETTING_TOO_LOW'		=> 'Antamasi arvo asetukselle “%1$s” on liian pieni. Vähimmäisarvo on %2$d.',
+	'SETTING_TOO_BIG'		=> 'Antamasi arvo asetukselle “%1$s” on liian suuri. Enimmäisarvo on %2$d.',	
 	'SETTING_TOO_LONG'		=> 'Antamasi arvo asetukselle “%1$s” on liian pitkä. Suurin sallittu pituus on %2$d.',
 	'SETTING_TOO_SHORT'		=> 'Antamasi arvo asetukselle “%1$s” ei ole tarpeeksi pitkä. Pienin sallittu pituus on %2$d.',
 	'SHOW_ALL_OPERATIONS'	=> 'Näytä kaikki toimenpiteet',
@@ -286,14 +286,14 @@ $lang = array_merge($lang, array(
 	'USERNAMES_EXPLAIN'		=> 'Laita jokainen käyttäjätunnus omalle rivillensä',
 	'USER_CONTROL_PANEL'	=> 'Käyttäjien hallintapaneeli',
 
-	'WARNING'				=> 'varoitus',
+	'WARNING'				=> 'Varoitus',
 ));
 
 // PHP info
 $lang = array_merge($lang, array(
 	'ACP_PHP_INFO_EXPLAIN'	=> 'Tällä sivulla on tietoa palvelimelle asennetusta PHP-versiosta. Tietoa löytyy ladatuista moduuleista, ympäristömuuttujista ja asetuksista. Näistä tiedoista voi olla hyötyä virhetilanteita ratkottaessa. Huomaa, että jotkut palveluntarjoajat saattavat rajoittaa tällä sivulla näkyviä tietoja tietoturvasyistä. Näitä tietoja ei pidä levittää julkisesti, paitsi jos phpBB:n <a href="https://www.phpbb.com/about/team/">virallinen tiimin jäsen</a> sitä kysyy tukifoorumilla.',
 
-	'NO_PHPINFO_AVAILABLE'	=> 'PHP-informaatiota ei voitu hakea. Phpinfo() on poistettu käytöstä.',
+	'NO_PHPINFO_AVAILABLE'	=> 'PHP-informaatiota ei voitu hakea. Phpinfo() on poistettu käytöstä tietoturvasyistä.',
 ));
 
 // Logs
@@ -315,7 +315,7 @@ $lang = array_merge($lang, array(
 
 // Index page
 $lang = array_merge($lang, array(
-	'ADMIN_INTRO'				=> 'Kiitos, että valitsit phpBB:n Keskustelufoorumiksesi. Tällä sivulla näet pikaisen silmäyksen erilaisista tilastoinneista. Vasemmalla puolella olevilla linkeillä voit muokata kaikkia foorumiin liittyviä asetuksia auttaen saamaan kaiken irti foorumikokemuksistasi. Jokaisella sivulla on ohjeet kuinka työkalua käytetään.',
+	'ADMIN_INTRO'				=> 'Kiitos, että valitsit phpBB:n keskustelufoorumiksesi. Tällä sivulla näet pikaisen silmäyksen erilaisista tilastoinneista. Vasemmalla puolella olevilla linkeillä voit muokata kaikkia foorumiin liittyviä asetuksia auttaen saamaan kaiken irti foorumikokemuksistasi. Jokaisella sivulla on ohjeet kuinka työkalua käytetään.',
 	'ADMIN_LOG'					=> 'Ylläpidon suorittamat toimenpiteet',
 	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'Tässä on viisi viimeisintä ylläpidon suorittamaa toimenpidettä. Voit katsoa täydelliset lokitiedot tietyillä asetuksilla seuraamalla alapuolella olevaa linkkiä.',
 	'AVATAR_DIR_SIZE'			=> 'Avatar-hakemiston koko',
@@ -326,13 +326,13 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Tietokantapalvelin',
 	'DATABASE_SIZE'			=> 'Tietokannan koko',
 	// Enviroment configuration checks, mbstring related
-'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Function overload ei ole asetettu oikein',
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Function overload ei ole asetettu oikein',
 	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> arvon tulee olla asetettu joko 0 tai 4. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
 	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Läpinäkyvä merkistönkoodaus ei ole asetettu oikein',
 	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> arvon tulee olla 0. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
-	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input merkistön konversio ei ole asetettu oikein',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP-input-merkistön muuntaminen ei ole asetettu oikein',
 	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> arvon tulee olla <samp>pass</samp>. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
-	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output merkistön konversio ei ole asetettu oikein',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP-output-merkistön muuntaminen ei ole asetettu oikein',
 	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> arvon tulee olla <samp>pass</samp>. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
 
 	'FILES_PER_DAY'		=> 'Liitetiedostoja päivässä',
@@ -346,18 +346,19 @@ $lang = array_merge($lang, array(
 	'NUMBER_TOPICS'		=> 'Viestiketjujen lukumäärä',
 	'NUMBER_USERS'		=> 'Käyttäjät',
 	'NUMBER_ORPHAN'		=> 'Orvot liitetiedostot',
-	'PHP_VERSION_OLD'	=> 'Palvelimen käyttämä PHP versio ei ole tuettu tulevien phpBB versioiden käyttämiseen. %sLisätietoja%s',
+	'PHP_VERSION_OLD'	=> 'Palvelimen käyttämä PHP-versio ei ole tuettu tulevien phpBB-versioiden käyttämiseen. %sLisätietoja%s',
 
 	'POSTS_PER_DAY'		=> 'Viestiä päivässä',
 
 	'PURGE_CACHE'			=> 'Tyhjennä välimuisti',
 	'PURGE_CACHE_CONFIRM'	=> 'Haluatko varmasti tyhjentää välimuistin?',
 	'PURGE_CACHE_EXPLAIN'	=> 'Tyhjennä kaikki välimuistiin liittyvät asiat. Tähän kuuluu mallineet ja suoritetut kyselyt',
+
 	'PURGE_SESSIONS'			=> 'Tyhjennä istunnot',
 	'PURGE_SESSIONS_CONFIRM'	=> 'Haluatko varmasti tyhjentää istunnot? Tämä kirjaa kaikki käyttäjät ulos.',
 	'PURGE_SESSIONS_EXPLAIN'	=> 'Tyhjennä istunnot. Tämä tyhjentää istuntoihin käytettävän taulun tietokannasta',
 
-	'RESET_DATE'					=> 'Muuta Keskustelufoorumin aloituspäivämäärä',
+	'RESET_DATE'					=> 'Muuta keskustelufoorumin aloituspäivämäärä',
 	'RESET_DATE_CONFIRM'			=> 'Haluatko varmasti asettaa aloituspäivämäärän uudestaan?',
 	'RESET_ONLINE'					=> 'Muuta vierailleiden käyttäjien määrää',
 	'RESET_ONLINE_CONFIRM'			=> 'Haluatko varmasti muuttaa vierailleiden käyttäjien määrää?',
@@ -387,7 +388,7 @@ $lang = array_merge($lang, array(
 	'VIEW_INACTIVE_USERS'	=> 'Näytä vahvistamattomat käyttäjät',
 
 	'WELCOME_PHPBB'			=> 'Tervetuloa phpBB:hen',
-    'WRITABLE_CONFIG'       => 'Konfigurointitiedostosi (config.php) on kirjoitettavissa. Suosittelemme, että muutat tiedoston oikeudet muotoon 640 tai ainakin 644 (esimerkiksi: <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php).',
+    'WRITABLE_CONFIG'       => 'Asetustiedostosi (config.php) on kirjoitettavissa. Suosittelemme, että muutat tiedoston oikeudet muotoon 640 tai ainakin 644 (esimerkiksi: <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php).',
 ));
 
 // Inactive Users
@@ -417,7 +418,7 @@ $lang = array_merge($lang, array(
 
 // Send statistics page
 $lang = array_merge($lang, array(
-	'EXPLAIN_SEND_STATISTICS'	=> 'Ole ystävällinen ja lähetä tilastotietoa palvelimesta phpBB:lle analysointia varten. Kaikki tiedot joista voi tunnistaa nettisivustosi on poistettu - lähetettävä tieto on täysin <strong>anonyymiä</strong>. Käytämme tätä tietoa kehittääksemme phpBB:tä. Tilastotiedot ovat julkisia ja me jaamme tämän tiedon myös PHP Projektin kanssa, jonka kehittämällä kielellä phpBB on luotu.',
+	'EXPLAIN_SEND_STATISTICS'	=> 'Ole ystävällinen ja lähetä tilastotietoa palvelimesta phpBB:lle analysointia varten. Kaikki tiedot joista voi tunnistaa nettisivustosi on poistettu - lähetettävä tieto on täysin <strong>anonyymiä</strong>. Käytämme tätä tietoa kehittääksemme phpBB:tä. Tilastotiedot ovat julkisia ja me jaamme tämän tiedon myös PHP-projektin kanssa, jonka kehittämällä kielellä phpBB on luotu.',
 	'EXPLAIN_SHOW_STATISTICS'	=> 'Käytä alapuolella olevaa nappulaa nähdäksesi lähetettävät tiedot.',
 	'DONT_SEND_STATISTICS'		=> 'Palaa ylläpitoon, mikäli et halua lähettää tilastotietoja.',
 	'GO_ACP_MAIN'				=> 'Mene ylläpidon aloitussivulle',
@@ -436,21 +437,21 @@ $lang = array_merge($lang, array(
 	'LOG_ACL_ADD_USER_GLOBAL_A_'		=> '<strong>Lisäsi tai muokkasi käyttäjän ylläpitäjän oikeuksia</strong><br />» %s',
 	'LOG_ACL_ADD_GROUP_GLOBAL_A_'		=> '<strong>Lisäsi tai muokkasi ryhmän ylläpitäjän oikeuksia</strong><br />» %s',
 
-	'LOG_ACL_ADD_ADMIN_GLOBAL_A_'		=> '<strong>Lisäsi tai muokkasi Ylläpitäjiä</strong><br />» %s',
+	'LOG_ACL_ADD_ADMIN_GLOBAL_A_'		=> '<strong>Lisäsi tai muokkasi ylläpitäjiä</strong><br />» %s',
 	'LOG_ACL_ADD_MOD_GLOBAL_M_'			=> '<strong>Lisäsi tai muokkasi valvojia</strong><br />» %s',
 
-	'LOG_ACL_ADD_USER_LOCAL_F_'			=> '<strong>Lisäsi tai muokkasi Käyttäjän pääsyä alueelle</strong> mistä %1$s<br />» %2$s',
-	'LOG_ACL_ADD_USER_LOCAL_M_'			=> '<strong>Lisäsi tai muokkasi Käyttäjän valvojan oikeutta</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_ADD_USER_LOCAL_F_'			=> '<strong>Lisäsi tai muokkasi käyttäjän pääsyä alueelle</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_ADD_USER_LOCAL_M_'			=> '<strong>Lisäsi tai muokkasi käyttäjän valvojan oikeutta</strong> mistä %1$s<br />» %2$s',
 	'LOG_ACL_ADD_GROUP_LOCAL_F_'		=> '<strong>Lisäsi tai muokkasi ryhmän pääsyä alueelle</strong> mistä %1$s<br />» %2$s',
-	'LOG_ACL_ADD_GROUP_LOCAL_M_'		=> '<strong>Lisäsi tai muokkasi Ryhmän valvojien oikeutta</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_ADD_GROUP_LOCAL_M_'		=> '<strong>Lisäsi tai muokkasi ryhmän valvojien oikeutta</strong> mistä %1$s<br />» %2$s',
 
-	'LOG_ACL_ADD_MOD_LOCAL_M_'			=> '<strong>Lisäsi tai muokkasi Valvojia</strong> mistä %1$s<br />» %2$s',
-	'LOG_ACL_ADD_FORUM_LOCAL_F_'		=> '<strong>Lisäsi tai muokkasi Keskustelualueen oikeuksia</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_ADD_MOD_LOCAL_M_'			=> '<strong>Lisäsi tai muokkasi valvojia</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_ADD_FORUM_LOCAL_F_'		=> '<strong>Lisäsi tai muokkasi keskustelualueen oikeuksia</strong> mistä %1$s<br />» %2$s',
 
-	'LOG_ACL_DEL_ADMIN_GLOBAL_A_'		=> '<strong>Poisti Ylläpitäjiä</strong><br />» %s',
+	'LOG_ACL_DEL_ADMIN_GLOBAL_A_'		=> '<strong>Poisti ylläpitäjiä</strong><br />» %s',
 	'LOG_ACL_DEL_MOD_GLOBAL_M_'			=> '<strong>Poisti valvojia</strong><br />» %s',
-	'LOG_ACL_DEL_MOD_LOCAL_M_'			=> '<strong>Poisti Valvojia</strong> mistä %1$s<br />» %2$s',
-	'LOG_ACL_DEL_FORUM_LOCAL_F_'		=> '<strong>Poisti Käyttäjän/Ryhmän oikeudet keskustelualueella</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_DEL_MOD_LOCAL_M_'			=> '<strong>Poisti valvojia</strong> mistä %1$s<br />» %2$s',
+	'LOG_ACL_DEL_FORUM_LOCAL_F_'		=> '<strong>Poisti käyttäjän/ryhmän oikeudet keskustelualueella</strong> mistä %1$s<br />» %2$s',
 
 	'LOG_ACL_TRANSFER_PERMISSIONS'		=> '<strong>Siirsi oikeudet käyttäjältä</strong><br />» %s',
 	'LOG_ACL_RESTORE_PERMISSIONS'		=> '<strong>Palautti omat oikeutensa testattuaan käyttäjää</strong><br />» %s',
@@ -499,7 +500,7 @@ $lang = array_merge($lang, array(
 	'LOG_CONFIG_COOKIE'			=> '<strong>Muutti evästeiden asetuksia</strong>',
 	'LOG_CONFIG_EMAIL'			=> '<strong>Muutti sähköpostiasetuksia</strong>',
 	'LOG_CONFIG_FEATURES'		=> '<strong>Muutti foorumin ominaisuuksia</strong>',
-	'LOG_CONFIG_LOAD'			=> '<strong>Muutti Kuormituksen asetuksia</strong>',
+	'LOG_CONFIG_LOAD'			=> '<strong>Muutti kuormituksen asetuksia</strong>',
 	'LOG_CONFIG_MESSAGE'		=> '<strong>Muutti yksityisviestien asetuksia</strong>',
 	'LOG_CONFIG_POST'			=> '<strong>Muutti viestien lähettämisen asetuksia</strong>',
 	'LOG_CONFIG_REGISTRATION'	=> '<strong>Muutti rekisteröitymisen asetuksia</strong>',
@@ -521,8 +522,8 @@ $lang = array_merge($lang, array(
 	'LOG_LOCK_POST'				=> '<strong>Lukitsi viestin</strong><br />» %s',
 	'LOG_MERGE'					=> '<strong>yhdisti viestiketjun</strong> viestiketjuun<br />»%s',
 	'LOG_MOVE'					=> '<strong>Siirsi viestiketjun</strong><br />» alueelta %1$s alueelle %2$s',
-	'LOG_PM_REPORT_CLOSED'		=> '<strong>Sulki YV ilmoituksen</strong><br />» %s',
-	'LOG_PM_REPORT_DELETED'		=> '<strong>Poisti YV ilmoituksen</strong><br />» %s',
+	'LOG_PM_REPORT_CLOSED'		=> '<strong>Sulki YV-ilmoituksen</strong><br />» %s',
+	'LOG_PM_REPORT_DELETED'		=> '<strong>Poisti YV-ilmoituksen</strong><br />» %s',
 	'LOG_POST_APPROVED'			=> '<strong>Hyväksyi viestin</strong><br />» %s',
 	'LOG_POST_DISAPPROVED'		=> '<strong>Hylkäsi viestin “%1$s” ja antoi syyn</strong><br />» %2$s',
 	'LOG_POST_EDITED'			=> '<strong>Muokkasi viestiä “%1$s” Kirjoittanut</strong><br />» %2$s',
@@ -549,8 +550,8 @@ $lang = array_merge($lang, array(
 	'LOG_DOWNLOAD_IP'			=> '<strong>Lisäsi IP:n/isäntänimen latauslistaan</strong><br />» %s',
 	'LOG_DOWNLOAD_REMOVE_IP'	=> '<strong>Poisti IP:n/isäntänimen latauslistasta</strong><br />» %s',
 
-	'LOG_ERROR_JABBER'		=> '<strong>Jabber Virhe</strong><br />» %s',
-	'LOG_ERROR_EMAIL'		=> '<strong>Sähköposti Virhe</strong><br />» %s',
+	'LOG_ERROR_JABBER'		=> '<strong>Jabber-virhe</strong><br />» %s',
+	'LOG_ERROR_EMAIL'		=> '<strong>Sähköposti-virhe</strong><br />» %s',
 	
 	'LOG_FORUM_ADD'							=> '<strong>Loi uuden alueen</strong><br />» %s',
 	'LOG_FORUM_COPIED_PERMISSIONS'			=> '<strong>Kopioi alueen oikeudet</strong> alueelta %1$s<br />» %2$s',
@@ -567,6 +568,7 @@ $lang = array_merge($lang, array(
 	'LOG_FORUM_MOVE_DOWN'					=> '<strong>Siirsi alueen</strong> %1$s <strong>alas</strong> %2$s',
 	'LOG_FORUM_MOVE_UP'						=> '<strong>Siirsi alueen</strong> %1$s <strong>ylös</strong> %2$s',
 	'LOG_FORUM_SYNC'						=> '<strong>Synkronoi alueen</strong><br />» %s',
+
 	'LOG_GENERAL_ERROR'	=> '<strong>Yleinen virhe</strong>: %1$s <br />» %2$s',
 
 	'LOG_GROUP_CREATED'		=> '<strong>Loi uuden käyttäjäryhmän</strong><br />» %s',
@@ -581,7 +583,7 @@ $lang = array_merge($lang, array(
 	'LOG_USERS_APPROVED'	=> '<strong>Hyväksyi käyttäjiä ryhmään</strong> %1$s<br />» %2$s',
 	'LOG_USERS_PENDING'		=> '<strong>Käyttäjä pyysi liittymistä ryhmään “%1$s” ja tarvitsee hyväksynnän</strong><br />» %2$s',
 
-	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>Kuvan luonnissa tapahtui virhe</strong><br />» Error in %1$s on line %2$s: %3$s',
+	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>Kuvan luonnissa tapahtui virhe</strong><br />» Virhe tiedostossa %1$s rivillä %2$s: %3$s',
 	'LOG_IMAGESET_ADD_DB'		=> '<strong>Lisäsi uuden kuvapaketin tietokantaan</strong><br />» %s',
 	'LOG_IMAGESET_ADD_FS'		=> '<strong>Lisäsi uuden kuvapaketin tiedostojärjestelmään</strong><br />» %s',
 	'LOG_IMAGESET_DELETE'		=> '<strong>Poisti kuvapaketin</strong><br />» %s',
@@ -589,7 +591,7 @@ $lang = array_merge($lang, array(
 	'LOG_IMAGESET_EDIT'			=> '<strong>Muokkasi kuvapakettia</strong><br />» %s',
 	'LOG_IMAGESET_EXPORT'		=> '<strong>Vei kuvapaketin</strong><br />» %s',
 	'LOG_IMAGESET_LANG_MISSING'		=> '<strong>Kuvapaketista puuttuu “%2$s” lokalisoitu versio</strong><br />» %1$s',
-	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>Virkisti “%2$s” Lokalisoidun kuvapaketin</strong><br />» %1$s',
+	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>Virkisti “%2$s” lokalisoidun kuvapaketin</strong><br />» %1$s',
 	'LOG_IMAGESET_REFRESHED'	=> '<strong>Virkisti kuvapaketin</strong><br />» %s',
 
 	'LOG_INACTIVE_ACTIVATE'	=> '<strong>Aktivoi aktivoimattomat käyttäjät</strong><br />» %s',
@@ -598,12 +600,12 @@ $lang = array_merge($lang, array(
 	'LOG_INSTALL_CONVERTED'	=> '<strong>Konvertoi %1$s ohjelmasta phpBB:hen %2$s</strong>',
 	'LOG_INSTALL_INSTALLED'	=> '<strong>Asensi phpBB %s ohjelman</strong>',
 
-	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>Session IP/browser/X_FORWARDED_FOR tarkistus epäonnistui</strong><br />»Käyttäjän IP "<em>%1$s</em>" Tarkistettiin istunnon IP:tä vasten "<em>%2$s</em>", käyttäjän selaimen merkkijono "<em>%3$s</em>" tarkistettiin käyttäjän istunnon selaimen merkkijonoa vasten "<em>%4$s</em>" ja käyttäjän X_FORWARDED_FOR merkkijono "<em>%5$s</em>" tarkistettiin käyttäjän istunnon X_FORWARDED_FOR merkkijonoa vasten "<em>%6$s</em>".',
+	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>Istunnon IP/selain/X_FORWARDED_FOR-tarkistus epäonnistui</strong><br />»Käyttäjän IP "<em>%1$s</em>" Tarkistettiin istunnon IP:tä vasten "<em>%2$s</em>", käyttäjän selaimen merkkijono "<em>%3$s</em>" tarkistettiin käyttäjän istunnon selaimen merkkijonoa vasten "<em>%4$s</em>" ja käyttäjän X_FORWARDED_FOR merkkijono "<em>%5$s</em>" tarkistettiin käyttäjän istunnon X_FORWARDED_FOR merkkijonoa vasten "<em>%6$s</em>".',
 
-	'LOG_JAB_CHANGED'			=> '<strong>Jabber tiliä muutettu</strong>',
-	'LOG_JAB_PASSCHG'			=> '<strong>Jabber salasana muutettu</strong>',
-	'LOG_JAB_REGISTER'			=> '<strong>Jabber tili rekisteröity</strong>',
-	'LOG_JAB_SETTINGS_CHANGED'	=> '<strong>Jabber asetuksia muutettu</strong>',
+	'LOG_JAB_CHANGED'			=> '<strong>Jabber-tiliä muutettu</strong>',
+	'LOG_JAB_PASSCHG'			=> '<strong>Jabber-salasana muutettu</strong>',
+	'LOG_JAB_REGISTER'			=> '<strong>Jabber-tili rekisteröity</strong>',
+	'LOG_JAB_SETTINGS_CHANGED'	=> '<strong>Jabber-asetuksia muutettu</strong>',
 
 	'LOG_LANGUAGE_PACK_DELETED'		=> '<strong>Poisti kielipaketin</strong><br />» %s',
 	'LOG_LANGUAGE_PACK_INSTALLED'	=> '<strong>Asensi kielipaketin</strong><br />» %s',
@@ -709,6 +711,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_NEW_PASSWORD'	=> '<strong>vaihtoi salasanan käyttäjälle</strong><br />» %s',
 	'LOG_USER_REACTIVATE'	=> '<strong>Pakotti käyttäjän varmistamaan tunnuksensa</strong><br />» %s',
 	'LOG_USER_REMOVED_NR'	=> '<strong>Poisti uuden käyttäjän statuksen</strong><br />» %s',
+
 	'LOG_USER_UPDATE_EMAIL'	=> '<strong>Käyttäjä "%1$s" vaihtoi sähköpostiosoitetta</strong><br />» osoitteesta "%2$s" osoitteeksi "%3$s"',
 	'LOG_USER_UPDATE_NAME'	=> '<strong>Vaihtoi käyttäjätunnusta</strong><br />» vanha "%1$s" uusi "%2$s"',
 	'LOG_USER_USER_UPDATE'	=> '<strong>Päivitti käyttäjän tiedot</strong><br />» %s',
@@ -731,6 +734,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_GROUP_JOIN'			=> '<strong>Käyttäjä liittyi ryhmään</strong><br />» %s',
 	'LOG_USER_GROUP_JOIN_PENDING'	=> '<strong>Käyttäjä liittyi ryhmään, mutta tarvitsee hyväksynnän</strong><br />» %s',
 	'LOG_USER_GROUP_RESIGN'			=> '<strong>Käyttäjä erosi ryhmästä</strong><br />» %s',
+
 	'LOG_WARNING_DELETED'		=> '<strong>Poisti varoituksen</strong><br />» %s',
 	'LOG_WARNINGS_DELETED'		=> '<strong>Poisti %2$s varoitusta</strong><br />» %1$s', // Example: '<strong>Deleted 2 user warnings</strong><br />» username'
 	'LOG_WARNINGS_DELETED_ALL'	=> '<strong>Poisti kaikki varoitukset</strong><br />» %s',
