@@ -40,10 +40,10 @@ $lang = array_merge($lang, array(
 		<p>Oikeudet ovat monipuoliset ja ne ovat ryhmitetty neljään pääluokkaan, jotka ovat:</p>
 
 		<h2>Yleiset asetukset</h2>
-		<p>Nämä asetukset ovat yleisiä asetuksia ja ne ovat voimassa kaikkialla keskustelufoorumilla. Nämä ovat vielä jaettuna käyttäjän oikeuksiin, Ryhmän oikeuksiin, Ylläpitäjiin ja päävalvojiin.</p>
+		<p>Nämä asetukset ovat yleisiä asetuksia ja ne ovat voimassa kaikkialla keskustelufoorumilla. Nämä ovat vielä jaettuna käyttäjän oikeuksiin, ryhmän oikeuksiin, ylläpitäjiin ja päävalvojiin.</p>
 
 		<h2>Alueeseen perustuvat oikeudet</h2>
-		<p>Nämä asetukset määrittelevät oikeuksia keskustelualue kohtaisesti. Nämä ovat vielä jaettuna alueen oikeuksiin, Alueen valvojat, Käyttäjän alueen oikeudet ja ryhmien oikeuksiin.</p>
+		<p>Nämä asetukset määrittelevät oikeuksia keskustelualue kohtaisesti. Nämä ovat vielä jaettuna alueen oikeuksiin, alueen valvojien oikeuksiin, käyttäjän alueen oikeuksiin ja ryhmien oikeuksiin.</p>
 
 		<h2>Oikeuksien roolit</h2>
 		<p>Näillä asetuksilla luodaan paketteja, jotka ovat varustettu erilaisilla oikeuksilla. Näillä paketeilla voidaan määritellä oikeudet myöhemmässä vaiheessa rooleina. Oletus roolit pitävät sisällään niin ison, kuin pienenkin foorumin koko ylläpidon. Kuitenkin jokaisessa neljästä pääryhmässä, voit lisätä, muokata ja poistaa haluamiasi rooleja.</p>
@@ -58,8 +58,8 @@ $lang = array_merge($lang, array(
 
 	'ACL_NEVER'				=> 'Ei koskaan',
 	'ACL_SET'				=> 'Aseta oikeuksia',
-	'ACL_SET_EXPLAIN'		=> 'Oikeudet perustuvat yksinkertaiseen <samp>KYLLÄ</samp>/<samp>EI</samp> järjestelmään. Mikäli asetat vaihtoehdon <samp>EI KOSKAAN</samp> käyttäjälle tai käyttäjäryhmälle ohittaa kaiken muun sille määritetyn asetuksen. Mikäli et halua asettaa tätä vaihtoehtoa käyttäjälle tai ryhmälle Valitse <samp>EI</samp>. Mikäli tälle asetukselle on määritetty arvo toisaalla. Sitä käytetään asetuksena, muussa tapauksessa <samp>EI KOSKAAN</samp> on oletuksena. Kaikki merkityt objektit (Valinta ruutu niiden edessä) kopioivat oikeudet määrittämästäsi paketista.',
-	'ACL_SETTING'			=> 'asetus',
+	'ACL_SET_EXPLAIN'		=> 'Oikeudet perustuvat yksinkertaiseen <samp>KYLLÄ</samp>/<samp>EI</samp>-järjestelmään. Mikäli asetat vaihtoehdon <samp>EI KOSKAAN</samp> käyttäjälle tai käyttäjäryhmälle, se ohittaa kaiken muun sille määritetyn asetuksen. Mikäli et halua asettaa tätä vaihtoehtoa käyttäjälle tai ryhmälle, valitse <samp>EI</samp>. Mikäli tälle asetukselle on määritetty arvo toisaalla, sitä käytetään asetuksena, muussa tapauksessa <samp>EI KOSKAAN</samp> on oletuksena. Kaikki merkityt kohteet (valintaruutu niiden edessä) kopioivat oikeudet määrittämästäsi paketista.',
+	'ACL_SETTING'			=> 'Asetus',
 
 	'ACL_TYPE_A_'			=> 'Ylläpitäjän oikeudet',
 	'ACL_TYPE_F_'			=> 'Alueen oikeudet',
@@ -77,19 +77,19 @@ $lang = array_merge($lang, array(
 	'ACL_VIEW_EXPLAIN'		=> 'Voit katsoa käyttäjäryhmällä voimassaolevat oikeudet. Punainen neliö tarkoittaa, että käyttäjällä/ryhmällä ei ole oikeutta suorittaa toimintoa. Vihreä neliö tarkoittaa, että käyttäjällä/ryhmällä on oikeus toiminnon suorittamiseen.',
 	'ACL_YES'				=> 'Kyllä',
 
-	'ACP_ADMINISTRATORS_EXPLAIN'				=> 'Täällä voit liittää ylläpitäjän oikeuksia käyttäjille tai ryhmille. Kaikki käyttäjät, joilla on ylläpitäjän oikeudet. Voivat katsoa ylläpidon hallintapaneelia.',
-	'ACP_FORUM_MODERATORS_EXPLAIN'				=> 'Täällä voit antaa käyttäjälle tai ryhmälle valvojan oikeuksia keskustelualueilla. Hallitaksesi käyttäjän pääsyä keskustelualueelle. Määrittääksesi yleisvalvojan oikeuksia tai ylläpitäjiä. Ole hyvä ja käytä asiaankuuluvaa sivua siihen tarkoitukseen.',
+	'ACP_ADMINISTRATORS_EXPLAIN'				=> 'Täällä voit liittää ylläpitäjän oikeuksia käyttäjille tai ryhmille. Kaikki käyttäjät, joilla on ylläpitäjän oikeudet, voivat katsoa ylläpidon hallintapaneelia.',
+	'ACP_FORUM_MODERATORS_EXPLAIN'				=> 'Täällä voit antaa käyttäjälle tai ryhmälle valvojan oikeuksia keskustelualueilla. Käytä asiaankuuluvaa sivua hallitaksesi käyttäjän pääsyä keskustelualueelle tai määrittääksesi yleisvalvojan oikeuksia tai ylläpitäjiä.',
 	'ACP_FORUM_PERMISSIONS_EXPLAIN'				=> 'Täällä voit määrätä, mitkä käyttäjät ja ryhmät pääsevät katsomaan mitäkin alueita. Määrittääksesi valvojia tai ylläpitäjiä. Ole hyvä ja käytä asiaankuuluvaa sivua siihen tarkoitukseen.',
 	'ACP_FORUM_PERMISSIONS_COPY_EXPLAIN'		=> 'Täällä voit kopioida oikeuksia yhdelle tai useammalle alueelle.',
-	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> 'Täällä voit antaa yleisvalvojan oikeudet käyttäjälle tai ryhmälle. Yleisvalvojat ovat muuten samanlaisia, kuin tavalliset valvojat, mutta heidän oikeudet ovat voimassa jokaisella alueella.',
+	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> 'Täällä voit antaa yleisvalvojan oikeudet käyttäjälle tai ryhmälle. Yleisvalvojat ovat muuten samanlaisia kuin tavalliset valvojat, mutta heidän oikeutensa ovat voimassa jokaisella alueella.',
 	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit antaa foorumin oikeuksia ryhmille.',
-	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'Täällä voit laittaa yleiset oikeudet ryhmille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne.. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne... Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne... Käyttäjäkohtaisia oikeuksia ei pitäisi muuttaa koskaan suoraan. Kannattaa aina muokata oikeuksia käyttäjäryhmän kautta ja asettaa käyttäjät näihin ryhmiin.',
-	'ACP_ADMIN_ROLES_EXPLAIN'					=> 'Täällä voit hallita ylläpitäjän roolin oikeuksia. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
-	'ACP_FORUM_ROLES_EXPLAIN'					=> 'Täällä voit hallita alueen oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
-	'ACP_MOD_ROLES_EXPLAIN'						=> 'Täällä voit hallita valvojien oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
-	'ACP_USER_ROLES_EXPLAIN'					=> 'Täällä voit hallita käyttäjän oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
+	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'Täällä voit laittaa yleiset oikeudet ryhmille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne. Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne. Käyttäjäkohtaisia oikeuksia ei pitäisi muuttaa koskaan suoraan. Kannattaa aina muokata oikeuksia käyttäjäryhmän kautta ja asettaa käyttäjät näihin ryhmiin.',
+	'ACP_ADMIN_ROLES_EXPLAIN'					=> 'Täällä voit hallita ylläpitäjän roolin oikeuksia. Roolit ovat voimassaolevia oikeuksia. Roolin muokkaaminen muuttaa myös kaikkien tämän roolin omaavien kohteiden oikeuksia.',
+	'ACP_FORUM_ROLES_EXPLAIN'					=> 'Täällä voit hallita alueen oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia. Roolin muokkaaminen muuttaa myös kaikkien tämän roolin omaavien kohteiden oikeuksia.',
+	'ACP_MOD_ROLES_EXPLAIN'						=> 'Täällä voit hallita valvojien oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia. Roolin muokkaaminen muuttaa myös kaikkien tämän roolin omaavien kohteiden oikeuksia.',
+	'ACP_USER_ROLES_EXPLAIN'					=> 'Täällä voit hallita käyttäjän oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia. Roolin muokkaaminen muuttaa myös kaikkien tämän roolin omaavien kohteiden oikeuksia.',
 	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit liittää keskustelualueen oikeuksia käyttäjille.',
-	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'Täällä voit laittaa yleiset oikeudet käyttäjille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne.. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne... Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne... Oikeuksien muokkaaminen usealle käyttäjälle kerralla on helppoa käyttäjäryhmien kautta. Käyttäjien henkilökohtaisia oikeuksia ei yleensä tarvitse muuttaa suoraan.',
+	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'Täällä voit laittaa yleiset oikeudet käyttäjille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne. Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne. Oikeuksien muokkaaminen usealle käyttäjälle kerralla on helppoa käyttäjäryhmien kautta. Käyttäjien henkilökohtaisia oikeuksia ei yleensä tarvitse muuttaa suoraan.',
 	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'		=> 'Täällä voit katsoa ylläpitäjän oikeuksia käyttäjälle tai ryhmälle.',
 	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS_EXPLAIN'	=> 'Täällä voit katsoa yleivalvojan oikeuksia valitsemillesi käytäjille tai ryhmille.',
 	'ACP_VIEW_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit katsoa keskustelualueen oikeuksia tietyille käyttäjille tai ryhmille.',
@@ -108,7 +108,8 @@ $lang = array_merge($lang, array(
 	'APPLY_ALL_PERMISSIONS'		=> 'Ota kaikki oikeudet käyttöön',
 	'APPLY_PERMISSIONS'			=> 'Ota oikeudet käyttöön',
 	'APPLY_PERMISSIONS_EXPLAIN'	=> 'Tälle kohteelle määritetyt oikeudet ja roolit asetetaan vain tälle ja merkityille kohteille.',
-	'AUTH_UPDATED'				=> 'Oikeudet ovat päivitetyt',
+	'AUTH_UPDATED'				=> 'Oikeudet päivitetty.',
+
 	'COPY_PERMISSIONS_CONFIRM'				=> 'Haluatko varmasti suorittaa toiminnon? Huomaa, että tämä toiminto ylikirjoittaa kohdealueen oikeudet.',
 	'COPY_PERMISSIONS_FORUM_FROM_EXPLAIN'	=> 'Lähde, josta haluat kopioida oikeudet.',
 	'COPY_PERMISSIONS_FORUM_TO_EXPLAIN'		=> 'Kohde, johon haluat siirtää oikeudet.',
@@ -121,7 +122,7 @@ $lang = array_merge($lang, array(
 
 	'DEFAULT'					=> 'Oletus',
 	'DELETE_ROLE'				=> 'Poista rooli',
-	'DELETE_ROLE_CONFIRM'		=> 'Haluatko varmsti poistaa tämän roolin? kohteet jotka käyttävät tätä roolia <strong>eivät</strong> eivät menetä oikeuksiansa.',
+	'DELETE_ROLE_CONFIRM'		=> 'Haluatko varmsti poistaa tämän roolin? Kohteet, jotka käyttävät tätä roolia, <strong>eivät</strong> menetä oikeuksiansa.',
 	'DISPLAY_ROLE_ITEMS'		=> 'Näytä tätä roolia käyttävät kohteet',
 
 	'EDIT_PERMISSIONS'			=> 'Muokkaa oikeuksia',
@@ -135,7 +136,7 @@ $lang = array_merge($lang, array(
 	'MANAGE_GROUPS'		=> 'Hallitse ryhmiä',
 	'MANAGE_USERS'		=> 'Hallitse käyttäjiä',
 
-	'NO_AUTH_SETTING_FOUND'		=> 'oikeusasetuksia ei ole määritelty.',
+	'NO_AUTH_SETTING_FOUND'		=> 'Oikeusasetuksia ei ole määritelty.',
 	'NO_ROLE_ASSIGNED'			=> 'Ei määrättyä roolia...',
 	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'Vaihtaminen tähän rooliin ei muuta oikealla puolella olevia asetuksia. Mikäli haluat poistaa kaikki oikeudet käytöstä. Käytä "Kaikki <samp>EI</samp>" linkkiä.',
 	'NO_ROLE_AVAILABLE'			=> 'Ei roolia saatavilla',
@@ -161,7 +162,7 @@ $lang = array_merge($lang, array(
 	'ROLE_ADMIN_FULL'			=> 'Täysi ylläpitäjä',
 	'ROLE_ADMIN_STANDARD'		=> 'Normaali ylläpitäjä',
 	'ROLE_ADMIN_USERGROUP'		=> 'Käyttäjän ja ryhmän ylläpitäjä',
-	'ROLE_FORUM_BOT'			=> 'Bot pääsy',
+	'ROLE_FORUM_BOT'			=> 'Bottioikeudet',
 	'ROLE_FORUM_FULL'			=> 'Täysi pääsy',
 	'ROLE_FORUM_LIMITED'		=> 'Rajoitettu pääsy',
 	'ROLE_FORUM_LIMITED_POLLS'	=> 'Rajoitettu pääsy + äänestykset',
@@ -187,7 +188,7 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_ADMIN_STANDARD'	=> 'Saa oikeudet useimpiin ylläpidon asetuksiin, mutta ei saa käyttää palvelimen tai järjestelmän työkaluja.',
 	'ROLE_DESCRIPTION_ADMIN_USERGROUP'	=> 'Voi hallita ryhmiä ja käyttäjiä: Voi muuttaa oikeuksia, asetuksia, hallita porttikieltoja ja hallita arvonimiä.',
 	'ROLE_DESCRIPTION_FORUM_BOT'		=> 'Tämä rooli on tarkoitettu boteille ja hakukoneiden spidereille.',
-	'ROLE_DESCRIPTION_FORUM_FULL'		=> 'Voi käyttää kaikkia alueen toimintoja, tiedotteiden luominen mukaanluettuna. Voi myös ohittaa aikarajat.<br />Tätä ei suositella normaalille käyttäjälle.',
+	'ROLE_DESCRIPTION_FORUM_FULL'		=> 'Voi käyttää kaikkia alueen toimintoja, tiedotteiden luominen mukaan lukien. Voi myös ohittaa aikarajat.<br />Tätä ei suositella normaalille käyttäjälle.',
 	'ROLE_DESCRIPTION_FORUM_LIMITED'	=> 'Voi käyttää joitakin alueen toimintoja, mutta ei voi lähettää liitetiedostoja tai käyttää viestien kuvakkeita.',
 	'ROLE_DESCRIPTION_FORUM_LIMITED_POLLS'	=> 'Kuten rajoitettu pääsy, mutta voi luoda äänestyksiä.',
 	'ROLE_DESCRIPTION_FORUM_NOACCESS'	=> 'Ei näe eikä pääse tälle alueelle.',
@@ -196,15 +197,15 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_FORUM_READONLY'	=> 'Voi lukea aluetta, mutta ei voi vastata tai kirjoittaa uutta avausta.',
 	'ROLE_DESCRIPTION_FORUM_STANDARD'	=> 'Voi käyttää suurinta osaa alueen toiminnoista liitetiedostot mukaanlukien, mutta ei voi lukita tai poistaa omaa viestiään tai luoda äänestystä.',
 	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'	=> 'Rooli uusien käyttäjien ryhmälle. Asetuksissa <samp>EI KOSKAAN</samp> estääkseen tiettyjen toimintojen käytön.',
-	'ROLE_DESCRIPTION_MOD_FULL'			=> 'Voi käyttää kaikkia valvojien toimintoja. Porttikiellot mukaanluettuna',
+	'ROLE_DESCRIPTION_MOD_FULL'			=> 'Voi käyttää kaikkia valvojien toimintoja, mukaan lukien porttikieltoja',
 	'ROLE_DESCRIPTION_MOD_QUEUE'		=> 'Voi käyttää valvojien viestijonoa hyväksyäkseen ja muokatakseen viestejä, mutta ei muuta.',
 	'ROLE_DESCRIPTION_MOD_SIMPLE'		=> 'Voi käyttää viestiketjun perustoimintoja. Ei voi lähettää varoituksia tai valvoa viestijonoa.',
 	'ROLE_DESCRIPTION_MOD_STANDARD'		=> 'Voi käyttää useimpia valvojien työkaluja, mutta ei voi antaa porttikieltoa tai vaihtaa viestin kirjoittajaa.',
 	'ROLE_DESCRIPTION_USER_FULL'		=> 'Voi käyttää kaikkia käyttäjilel tarjolla olevia toimintoja, Mukaanluettuna käyttäjätunuksen vaihtaminen ja aikarajojen ohittaminen.<br />Ei suositeltava toimenpide.',
 	'ROLE_DESCRIPTION_USER_LIMITED'		=> 'Voi käyttää joitakin käyttäjien toimintoja. Liitetiedostot, sähköposti ja pikaviestit eivät ole sallittuja.',
-	'ROLE_DESCRIPTION_USER_NOAVATAR'	=> 'Rajoitetut opikeudet eikä saa käyttää avataria.',
+	'ROLE_DESCRIPTION_USER_NOAVATAR'	=> 'Rajoitetut oikeudet eikä saa käyttää avataria.',
 	'ROLE_DESCRIPTION_USER_NOPM'		=> 'Rajoitetut oikeudet ja ei saa käyttää yksityisviestejä.',
-	'ROLE_DESCRIPTION_USER_STANDARD'	=> 'Pääsee käyttämään suurinta osa, mutta ei kaikkia toimintoja. Ei voi vaihtaa käyttäjän nimeä tai ohittaa aikarajoja, esimerkiksi.',
+	'ROLE_DESCRIPTION_USER_STANDARD'	=> 'Pääsee käyttämään suurinta osaa toiminnoista, mutta ei kaikkia toimintoja. Esimerkiksi ei voi vaihtaa käyttäjän nimeä tai ohittaa aikarajoja.',
 	'ROLE_DESCRIPTION_USER_NEW_MEMBER'	=> 'Rooli uusien käyttäjien ryhmälle. Asetuksissa <samp>EI KOSKAAN</samp> estääkseen tiettyjen toimintojen käytön.',
 	
 	'ROLE_DESCRIPTION_EXPLAIN'		=> 'Voit lisätä lyhyen kuvauksen mitä tämä rooli tekee tai mihin käyttöön se on tarkoitettu. Syöttämäsi teksti näytetään myös oikeudet sivulla.',
@@ -215,10 +216,10 @@ $lang = array_merge($lang, array(
 	'ROLE_NAME_ALREADY_EXIST'		=> 'Rooli nimeltä <strong>%s</strong> on jo olemassa tämän tyyppiselle oikeudelle.',
 	'ROLE_NOT_ASSIGNED'				=> 'Roolia ei ole vielä annettu.',
 
-	'SELECTED_FORUM_NOT_EXIST'		=> 'valitsemaasi aluetta/alueita ei ole olemassa',
-	'SELECTED_GROUP_NOT_EXIST'		=> 'Valitsemaasi tyhmää/ryhmiä ei ole olemassa',
+	'SELECTED_FORUM_NOT_EXIST'		=> 'Valitsemaasi aluetta/alueita ei ole olemassa',
+	'SELECTED_GROUP_NOT_EXIST'		=> 'Valitsemaasi ryhmää/ryhmiä ei ole olemassa',
 	'SELECTED_USER_NOT_EXIST'		=> 'Valitsemaasi käyttäjää/käyttäjiä ei ole olemassa',
-	'SELECT_FORUM_SUBFORUM_EXPLAIN'	=> 'valitsemastasi alueesta otetaan myös sisäalueet mukaan',
+	'SELECT_FORUM_SUBFORUM_EXPLAIN'	=> 'Valitsemastasi alueesta otetaan myös sisäalueet mukaan',
 	'SELECT_ROLE'					=> 'Valitse rooli...',
 	'SELECT_TYPE'					=> 'Valitse tyyppi',
 	'SET_PERMISSIONS'				=> 'Aseta oikeudet',
@@ -226,7 +227,7 @@ $lang = array_merge($lang, array(
 	'SET_USERS_PERMISSIONS'			=> 'Aseta käyttäjän oikeudet',
 	'SET_USERS_FORUM_PERMISSIONS'	=> 'Aseta käyttäjän oikeudet alueella',
 
-	'TRACE_DEFAULT'					=> 'Oletuksena kaikki oikeudet ovat <samp>EI</samp> (määrittämätön). Jotta sen voi ohittaa jollain toisella asetuksella.',
+	'TRACE_DEFAULT'					=> 'Oletuksena kaikki oikeudet ovat <samp>EI</samp> (määrittämätön), jotta sen voi ohittaa jollain toisella asetuksella.',
 	'TRACE_FOR'						=> 'Jäljitä',
 	'TRACE_GLOBAL_SETTING'			=> '%s (Yleinen)',
 	'TRACE_GROUP_NEVER_TOTAL_NEVER'	=> 'Tämän ryhmien oikeuksien asetus on asetettu <samp>EI KOSKAAN</samp> kuten asetukset yhteensä, joten vanhat asetukset pidetään.',
@@ -235,7 +236,7 @@ $lang = array_merge($lang, array(
 	'TRACE_GROUP_NEVER_TOTAL_NO_LOCAL'	=> 'Tämän ryhmän oikeudet tälle alueelle on asetettu <samp>EI KOSKAAN</samp>, mistä tulee uusi yhteisarvo, sillä sitä ei oltu asetettu vielä. (Aseta <samp>EI</samp>).',
 	'TRACE_GROUP_NEVER_TOTAL_YES'	=> 'Tämän ryhmien oikeuksien asetus on asetettu <samp>EI KOSKAAN</samp> joks ohittaa <samp>KYLLÄ</samp> ja <samp>EI KOSKAAN</samp> asetukset tälle käyttäjälle.',
 	'TRACE_GROUP_NEVER_TOTAL_YES_LOCAL'	=> 'Tämän ryhmän oikeudet tälle alueelle on asetettu <samp>EI KOSKAAN</samp>, joka muuttaa asetuksen <samp>KYLLÄ</samp> muotoon <samp>EI KOSKAAN</samp> tälle käyttäjälle.',
-	'TRACE_GROUP_NO'				=> 'Tämän ryhmän oikeus on (Aseta <samp>EI</samp> joten yhteisarvo pidetään.',
+	'TRACE_GROUP_NO'				=> 'Tämän ryhmän oikeus on <samp>EI</samp>, joten yhteisarvo pidetään.',
 	'TRACE_GROUP_NO_LOCAL'			=> 'Oikeudet on määritelty <samp>EI</samp> tällä alueella olevalle ryhmälle, joten vanha arvo pidetään.',
 	'TRACE_GROUP_YES_TOTAL_NEVER'	=> 'Tämän ryhmän oikeudet on määritelty <samp>KYLLÄ</samp>, mutta arvoa <samp>EI KOSKAAN</samp> ei voida ylikirjoittaa.',
 	'TRACE_GROUP_YES_TOTAL_NEVER_LOCAL'	=> 'Tämän ryhmän oikeudet tällä alueella on määritelty <samp>KYLLÄ</samp>, mutta arvoa <samp>EI KOSKAAN</samp> ei voida ylikirjoittaa.',
@@ -247,24 +248,24 @@ $lang = array_merge($lang, array(
 	'TRACE_RESULT'					=> 'Jäljityksen tulos',
 	'TRACE_SETTING'					=> 'Jäljityksen asetukset',
 
-	'TRACE_USER_GLOBAL_YES_TOTAL_YES'		=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>KYLLÄ</samp> Mutta yhteisarvo on jo määritelty <samp>KYLLÄ</samp>, joten yhtisarvo pidetään. %sJäljitä yleiset oikeudet%s',
-	'TRACE_USER_GLOBAL_YES_TOTAL_NEVER'		=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>KYLLÄ</samp> joka ylikirjoittaa tämänhetkisen tuloksen <samp>EI KOSKAAN</samp>. %sJäljitä yleiset oikeudet%s',
-	'TRACE_USER_GLOBAL_NEVER_TOTAL_KEPT'	=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>EI KOSKAAN</samp> mikä ei vaikuta paikallisiin oikeuksiin. %sJäljitä yleiset oikeudet%s',
+	'TRACE_USER_GLOBAL_YES_TOTAL_YES'		=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>KYLLÄ</samp>, mutta yhteisarvo on jo määritelty <samp>KYLLÄ</samp>, joten yhtisarvo pidetään. %sJäljitä yleiset oikeudet%s',
+	'TRACE_USER_GLOBAL_YES_TOTAL_NEVER'		=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>KYLLÄ</samp>, joka ylikirjoittaa tämänhetkisen tuloksen <samp>EI KOSKAAN</samp>. %sJäljitä yleiset oikeudet%s',
+	'TRACE_USER_GLOBAL_NEVER_TOTAL_KEPT'	=> 'Tämän alueen itsenäiset käyttäjän oikeudet arvioituu <samp>EI KOSKAAN</samp>, mikä ei vaikuta paikallisiin oikeuksiin. %sJäljitä yleiset oikeudet%s',
 
 	'TRACE_USER_FOUNDER'					=> 'Tämä käyttäjä on merkitty perustajaksi, joten ylläpitäjän oikeudet ovat automaattiseti voimassa.',
 	'TRACE_USER_FOUNDER'					=> 'Tämä käyttäjä on perustaja, joten ylläpitäjän asetukset ovat aina <samp>KYLLÄ</samp>.',
-	'TRACE_USER_KEPT'						=> 'Käyttäjän oikeus on <samp>EI</samp> Joten vanha yhteisarvo pidetään.',
+	'TRACE_USER_KEPT'						=> 'Käyttäjän oikeus on <samp>EI</samp>, joten vanha yhteisarvo pidetään.',
 	'TRACE_USER_KEPT_LOCAL'					=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>EI</samp>, joten vanha arvo pidetään.',
 	'TRACE_USER_NEVER_TOTAL_NEVER'			=> 'Käyttäjän oikeus on asetettu <samp>EI KOSKAAN</samp> ja yhteisarvo on EI KOSKAAN, joten mitään ei muuteta.',
 	'TRACE_USER_NEVER_TOTAL_NEVER_LOCAL'	=> 'Käyttäjän oikeus on asetettu <samp>EI KOSKAAN</samp> ja yhteisarvo on asetettu <samp>EI KOSKAAN</samp>, joten mitään ei muuteta.',
 	'TRACE_USER_NEVER_TOTAL_NO'				=> 'Käyttäjän oikeus on asetettu <samp>EI KOSKAAN</samp> josta tulee yhteisarvo, koska asetus oli <samp>EI</samp>.',
-	'TRACE_USER_NEVER_TOTAL_NO_LOCAL'		=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>NEVER</samp> which becomes the total value because it was set to NO.',
+	'TRACE_USER_NEVER_TOTAL_NO_LOCAL'		=> 'Käyttäjän oikeuksiksi tälle alueelle on asetettu <samp>EI KOSKAAN</samp>, josta tulee yhteisarvo, koska asetus oli EI.',
 	'TRACE_USER_NEVER_TOTAL_YES'			=> 'Käyttäjän oikeus on asetettu <samp>EI KOSKAAN</samp> ja se ylikirjoittaa asetuksen KYLLÄ.',
-	'TRACE_USER_NEVER_TOTAL_YES_LOCAL'		=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>NEVER</samp> and overwrites the previous <samp>YES</samp>.',
+	'TRACE_USER_NEVER_TOTAL_YES_LOCAL'		=> 'Käyttäjän oikeuksiksi tälle alueelle on asetettu <samp>EI KOSKAAN</samp>, joka ylikirjoittaa aiemman arvon <samp>KYLLÄ</samp>.',
 	'TRACE_USER_NO_TOTAL_NO'				=> 'Käyttäjän oikeus on <samp>EI</samp> ja yhteisarvo on <samp>EI</samp>, joten oletusarvo on <samp>EI KOSKAAN</samp>.',
 	'TRACE_USER_NO_TOTAL_NO_LOCAL'			=> 'Käyttäjän oikeudet tälle alueelle on <samp>EI</samp> ja myös yhteisarvo on EI, joten tuloksena on <samp>EI KOSKAAN</samp>.',
 	'TRACE_USER_YES_TOTAL_NEVER'			=> 'Käyttäjän oikeus on asetettu <samp>KYLLÄ</samp> Mutta yhteisarvoa <samp>EI KOSKAAN</samp> ei voida ylikirjoittaa.',
-	'TRACE_USER_YES_TOTAL_NEVER_LOCAL'		=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>YES</samp>, mutta asetusta <samp>EI KOSKAAN</samp> ei voida ylikirjoittaa.',
+	'TRACE_USER_YES_TOTAL_NEVER_LOCAL'		=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>KYLLÄ</samp>, mutta asetusta <samp>EI KOSKAAN</samp> ei voida ylikirjoittaa.',
 	'TRACE_USER_YES_TOTAL_NO'				=> 'Käyttäjän oikeus on asetettu <samp>KYLLÄ</samp> josta tulee yhteisarvo, koska asetus oli laietttu <samp>EI</samp>.',
 	'TRACE_USER_YES_TOTAL_NO_LOCAL'			=> 'Käyttäjän oikeudet tälle alueelle on asetettu <samp>KYLLÄ</samp>, josta tulee uusi yhteisarvo, sillä asetus oli asetettu <samp>EI</samp>.',
 	'TRACE_USER_YES_TOTAL_YES'				=> 'Käyttäjän oikeus on asetettu <samp>KYLLÄ</samp> ja yhteisarvo on asetettu <samp>KYLLÄ</samp>, joten mitään ei muuteta.',
