@@ -36,18 +36,18 @@ if (empty($lang) || !is_array($lang))
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 
 $lang = array_merge($lang, array(
-	'ACP_IMAGESETS_EXPLAIN'	=> 'Kuvapaketteihin kuuluvat kaikki keskustelufoorumilla käytössä olevat kuvat mukaanlukien myös käytettävästä tyylistä riippumattomat kuvat. Voit ladata kuvapaketteja koneellesi, muokata niitä, poistaa ja halutessasi lisätä uusia paketteja.',
+	'ACP_IMAGESETS_EXPLAIN'	=> 'Kuvapaketteihin kuuluvat kaikki keskustelufoorumilla käytössä olevat kuvat, mukaan lukien myös käytettävästä tyylistä riippumattomat kuvat. Voit ladata kuvapaketteja koneellesi, muokata niitä, poistaa ja halutessasi lisätä uusia paketteja.',
 	'ACP_STYLES_EXPLAIN'	=> 'Täällä voit muokata käytettävissä olevia tyylejä. Tyyliin kuuluu mallineet, teemat ja kuvapaketit. Voit muokata jo asennettuja tyylejä, poistaa, ottaa käyttöön, luoda tai tuoda uusia. Voit katsoa miltä uusi tyyli näyttää käyttämällä esikatselua. Oletustyyli on merkitty tähtimerkillä (*). Tilasto näyttää myös kuinka monta käyttäjää on asettanut tietyn tyylin omaksi tyylikseen. Huomaa, että käyttäjän tyylin ohitus ei näy tässä listassa.',
-	'ACP_TEMPLATES_EXPLAIN'	=> 'mallineet sisältävät kaiken tarvittavan kuvauksen sivun rakentamiseksi. Täällä voit muokata olemassa olevia mallineita, postaa, viedä, tuoda uusia ja esikatsella. Voit myös muokata BBCoden käyttämää koodia.',
+	'ACP_TEMPLATES_EXPLAIN'	=> 'Mallineet sisältävät kaiken tarvittavan kuvauksen sivun rakentamiseksi. Täällä voit muokata olemassa olevia mallineita, poistaa, viedä, tuoda uusia ja esikatsella. Voit myös muokata BBCoden käyttämää koodia.',
 	'ACP_THEMES_EXPLAIN'	=> 'Täällä voit luoda, asentaa, muokata, poistaa ja viedä mallineita. Teemat ovat kokoelma värejä ja kuvia, jotka lisätään käytettävissä olevaan mallinein, jossa luodaan keskustelufoorumin perus näkymä. Käytettävissä olevat vaihtoehdot riippuvat palvelimen asetuksista ja phpBB asennuksesta. Katso lisätietoja käyttö-oppaasta. Huomaa, että luodessasi uutta teemaa voit halutessasi käyttää vanhaa teemaa pohjana.',
 	'ADD_IMAGESET'			=> 'Luo kuvapaketti',
-	'ADD_IMAGESET_EXPLAIN'	=> 'Täällä voit luoda uusia kuvapaketteja. Palvelimen asetuksista ja tiedostojen oikeuksista riippuen sinulla voi olla enemmän vaihtoehtoja käytettävissä. Voit esimerkiksi perustaa tämän kuvapaketin olemassa olevien mukaan. Voit mahdollisesti ladata (store-hakemistosta) varastoidun kuvapaketin. Mikäli käytät varastoa, Kuvapaketin nimi voidaan ottaa vaihtoehtoisesti myös varastoidun paketin nimestä (Tämän tehdäksesi, jätä nimikenttä tyhjäksi).',
+	'ADD_IMAGESET_EXPLAIN'	=> 'Täällä voit luoda uusia kuvapaketteja. Palvelimen asetuksista ja tiedostojen oikeuksista riippuen sinulla voi olla enemmän vaihtoehtoja käytettävissä. Voit esimerkiksi perustaa tämän kuvapaketin olemassa olevien mukaan. Voit mahdollisesti ladata (store-hakemistosta) varastoidun kuvapaketin. Mikäli käytät varastoa, kuvapaketin nimi voidaan ottaa vaihtoehtoisesti myös varastoidun paketin nimestä (tämän tehdäksesi, jätä nimikenttä tyhjäksi).',
 	'ADD_STYLE'				=> 'Luo tyyli',
-	'ADD_STYLE_EXPLAIN'		=> 'Täällä voit luoda uuden tyylin. Palvelimen konfiguraatiosta ja tiedostojen oikeuksista riippuen sinulla voi olla lisä-asetuksia käytössäsi. Voit esimerkiksi käyttää uden tyylin pohjanan jotain vanhaa tyyliä. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda tyylin arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat tyylin arkistoon. Sen nimi määritellään automaattisesti.',
+	'ADD_STYLE_EXPLAIN'		=> 'Täällä voit luoda uuden tyylin. Palvelimen asetuksista ja tiedostojen oikeuksista riippuen sinulla voi olla lisäasetuksia käytössäsi. Voit esimerkiksi käyttää uden tyylin pohjanan jotain vanhaa tyyliä. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda tyylin arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat tyylin arkistoon. Sen nimi määritellään automaattisesti.',
 	'ADD_TEMPLATE'			=> 'Luo malline',
-	'ADD_TEMPLATE_EXPLAIN'	=> 'Täällä voit lisätä uuden mallineen. Palvelimen konfiguraatiosta ja tiedostojen oikeuksista riippuen sinulla voi olla lisä-asetuksia käytössäsi. Voit esimerkiksi käyttää uden tyylin pohjanan jotain vanhaa mallinea. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda mallineen arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat mallineen. Sen nimi voidaan vaihtoehtoisesti ottaa myös arkistotiedoston nimestä.',
+	'ADD_TEMPLATE_EXPLAIN'	=> 'Täällä voit lisätä uuden mallineen. Palvelimen asetuksista ja tiedostojen oikeuksista riippuen sinulla voi olla lisäasetuksia käytössäsi. Voit esimerkiksi käyttää uden tyylin pohjanan jotain vanhaa mallinea. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda mallineen arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat mallineen. Sen nimi voidaan vaihtoehtoisesti ottaa myös arkistotiedoston nimestä.',
 	'ADD_THEME'				=> 'Luo teema',
-	'ADD_THEME_EXPLAIN'		=> 'Täällä voit luoda uuden teeman. Palvelimen konfiguraatiosta ja tiedostojen oikeuksista riippuen sinulla voi olla lisä-asetuksia käytössäsi. Voit esimerkiksi käyttää uden teeman pohjanan jotain vanhaa teemaa. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda teeman arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat teeman. Sen nimi voidaan vaihtoehtoisesti ottaa myös arkistotiedostosta (Tämän tehdäksesi jätä nimi tyhjäksi)',
+	'ADD_THEME_EXPLAIN'		=> 'Täällä voit luoda uuden teeman. Palvelimen asetuksista ja tiedostojen oikeuksista riippuen sinulla voi olla lisäasetuksia käytössäsi. Voit esimerkiksi käyttää uden teeman pohjanan jotain vanhaa teemaa. Voit myös mahdollisesti siirtää suoraan palvelimelle tai tuoda teeman arkistotiedostoon (store-hakemistosta). Mikäli siirrät tai lataat teeman. Sen nimi voidaan vaihtoehtoisesti ottaa myös arkistotiedostosta (tämän tehdäksesi jätä nimi tyhjäksi)',
 	'ARCHIVE_FORMAT'		=> 'Tiedoston tyyppi',
 	'AUTOMATIC_EXPLAIN'		=> 'Jätä tyhjäksi yrittääksesi automaattista tunnistusta.',
 
@@ -59,7 +59,7 @@ $lang = array_merge($lang, array(
 
 	'CACHE'							=> 'Välimuisti',
 	'CACHE_CACHED'					=> 'Välimuistissa',
-	'CACHE_FILENAME'				=> 'malline tiedosto',
+	'CACHE_FILENAME'				=> 'Mallinetiedosto',
 	'CACHE_FILESIZE'				=> 'Tiedoston koko',
 	'CACHE_MODIFIED'				=> 'Muokattu',
 	'CONFIRM_IMAGESET_REFRESH'		=> 'Haluatko varmasti virkistää kuvapaketit uudestaan? Kuvapaketin asetustiedosto ylikirjoittaa kaikki editorissa annetut tiedot.',
@@ -84,7 +84,7 @@ $lang = array_merge($lang, array(
     'DELETE_THEME'              => 'Poista teema',
     'DELETE_THEME_EXPLAIN'      => 'Täällä voit poistaa valitsemasi teeman tietokannasta. Huomaa, että toimintoa ei voi peruuttaa. Teeman vienti talteen myöhempää käyttöä varten on suositeltavaa.',
 	'DETAILS'					=> 'Tiedot',
-	'DIMENSIONS_EXPLAIN'		=> 'Valitsemalla kyllä tähän. Voit lisätä leveys/korkeus arvot.',
+	'DIMENSIONS_EXPLAIN'		=> 'Valitsemalla kyllä tähän voit lisätä leveys-/korkeusarvot.',
 
 	'EDIT_DETAILS_IMAGESET'				=> 'Muokkaa kuvapaketin yksityiskohtia',
 	'EDIT_DETAILS_IMAGESET_EXPLAIN'		=> 'Täällä voit muokata kuvapaketin yksityiskohtia, kuten sen nimeä.',
@@ -93,14 +93,14 @@ $lang = array_merge($lang, array(
 	'EDIT_DETAILS_TEMPLATE'				=> 'Muokkaa mallineen yksityiskohtia',
 	'EDIT_DETAILS_TEMPLATE_EXPLAIN'		=> 'Täällä voit muokata templatteihin liittyviä yksityiskohta, kuten sen nimeä. Sinulla voi olla mahdollisuus siirtää tyylitiedoston tallennuspaikka tiedostojärjestelmästä tietokantaan, tai päinvastoin. Tämä vaihtoehto riippuu palvelimen PHP konfiguraatiosta voiko palvelin kirjoittaa mallineihin.',
 	'EDIT_DETAILS_THEME'				=> 'Muokkaa teeman yksityiskohtia',
-	'EDIT_DETAILS_THEME_EXPLAIN'		=> 'Täällä voit muoksts teemaan liittyviä yksityiskohta, kuten sen nimeä. Sinulla voi olla mahdollisuus siirtää tyylitiedoston tallennuspaikka tiedostojärjestelmästä tietokantaan, tai päinvastoin. Tämä vaihtoehto riippuu palvelimen PHP konfiguraatiosta voiko palvelin kirjoittaa tyylitiedostoon.',
+	'EDIT_DETAILS_THEME_EXPLAIN'		=> 'Täällä voit muoksta teemaan liittyviä yksityiskohta, kuten sen nimeä. Sinulla voi olla mahdollisuus siirtää tyylitiedoston tallennuspaikka tiedostojärjestelmästä tietokantaan, tai päinvastoin. Tämä vaihtoehto riippuu palvelimen PHP-asetuksista sekä siitä, voiko palvelin kirjoittaa tyylitiedostoon.',
 	'EDIT_IMAGESET'						=> 'Muokkaa kuvapakettia',
 	'EDIT_IMAGESET_EXPLAIN'				=> 'Täällä voit muokata yksittäisiä kuvia, jotka määrittävät kuvapaketin. Voit myös määrittää kuvalle koon. Kuvan koon määrittäminen ei ole pakollista, mutta se voi auttaa ratkaisemaan ongelmia, joita joillain selaimilla voi olla sivun näyttämisessä. Mikäli et määrittele kokoa. Tietokannan koko pienenee hieman.',
 	'EDIT_TEMPLATE'						=> 'Muokkaa mallinea',
-	'EDIT_TEMPLATE_EXPLAIN'				=> 'Täällä voit muokata mallinepakettia suoraan. Huomaa, että nämä muutokset ovat pysyviä, eikä niitä voida perua sen jälkeen, kun olet lähettänyt muutokset. Mikäli PHP voi kirjoittaa palvelimen tiedostoihin. Kaikki muokkaukset tehdään suoraan niihin. Mikäli PHP ei voi kirjoittaa tiedostoihin. Muokkaukset tehdään tietokantaan ja vain sitä muokataan. Ole huolellinen, kun muokkaat mallinepakettia, Muista sulkea kaikki lausekkeet {XXXX} Ja suhteelliset käskyt.',
-	'EDIT_TEMPLATE_STORED_DB'			=> 'mallinepaketti ei ole kirjoitettavissa, joten muokkaukset tallennettiin tietokantaan.',
+	'EDIT_TEMPLATE_EXPLAIN'				=> 'Täällä voit muokata mallinepakettia suoraan. Huomaa, että nämä muutokset ovat pysyviä, eikä niitä voida perua sen jälkeen, kun olet lähettänyt muutokset. Mikäli PHP voi kirjoittaa palvelimen tiedostoihin, kaikki muokkaukset tehdään suoraan niihin. Mikäli PHP ei voi kirjoittaa tiedostoihin, muokkaukset tehdään tietokantaan ja vain sitä muokataan. Ole huolellinen muokatessasi mallinepakettia. Muista sulkea kaikki lausekkeet {XXXX} ja suhteelliset käskyt.',
+	'EDIT_TEMPLATE_STORED_DB'			=> 'Mallinepaketti ei ole kirjoitettavissa, joten muokkaukset tallennettiin tietokantaan.',
 	'EDIT_THEME'						=> 'Muokkaa teemaa',
-	'EDIT_THEME_EXPLAIN'				=> 'Täällä voit muokata valitsemaasi teemaa. Vaihtaa värejä, kuvia, jne. Voit vaihtaa pois yksinkertaisesta näkymästä, jossa voit vaihtaa värejä, jne. Ja siirtyä tarkempaan näkymään, jossa voit muokata "raakaa CSS tietoa". Raaka muokkaus antaa sinun määritellä myös omia muokkauksia, kuten reunuksia, jne. Käytä vain niitä parametrejä, joita tarvitse ja jätä mut tyhjiksi.',
+	'EDIT_THEME_EXPLAIN'				=> 'Täällä voit muokata valitsemaasi teemaa, vaihtaa värejä, kuvia, jne. Voit vaihtaa pois yksinkertaisesta näkymästä, jossa voit vaihtaa värejä, jne. ja siirtyä tarkempaan näkymään, jossa voit muokata "raakaa CSS-tietoa". Raaka muokkaus antaa sinun määritellä myös omia muokkauksia, kuten reunuksia, jne. Käytä vain niitä parametrejä, joita tarvitset ja jätä muut tyhjiksi.',
 	'EDIT_THEME_STORED_DB'				=> 'Tyylitiedosto ei ole kirjoitettavissa, joten muutokset tallennettiin tietokantaan.',
 	'EDIT_THEME_STORE_PARSED'			=> 'Tämä teema vaatii tyylitiedostonsa suorittamista. Tämä on mahdollista vain, mikäli se on tallennettu tietokantaan.',
     'EDITOR_DISABLED'               => 'Tyylin muokakus on poissa käytöstä.',
@@ -114,7 +114,7 @@ $lang = array_merge($lang, array(
 
 	'GLOBAL_IMAGES'			=> 'Yleinen',
 
-	'HIDE_CSS'				=> 'Piilota raaka CSS tieto',
+	'HIDE_CSS'				=> 'Piilota raaka CSS-tieto',
 
 	'IMAGE_WIDTH'				=> 'Kuvan leveys',
 	'IMAGE_HEIGHT'				=> 'Kuvan korkeus',
@@ -160,7 +160,7 @@ $lang = array_merge($lang, array(
 	'IMG_ICON_FRIEND'		=> 'Lisää ystäväksi',
 	'IMG_ICON_FOE'			=> 'Lisää vihamieheksi',
 
-	'IMG_FORUM_LINK'			=> 'Alue linkki',
+	'IMG_FORUM_LINK'			=> 'Aluelinkki',
 	'IMG_FORUM_READ'			=> 'Alue',
 	'IMG_FORUM_READ_LOCKED'		=> 'Alue on lukittu',
 	'IMG_FORUM_READ_SUBFORUM'	=> 'Sisäalueet',
@@ -173,9 +173,9 @@ $lang = array_merge($lang, array(
 	'IMG_TOPIC_MOVED'			=> 'Viestiketju on siirretty',
 
 	'IMG_TOPIC_READ'				=> 'Viestiketju',
-	'IMG_TOPIC_READ_MINE'			=> 'Viestiketju johon olen vastannut',
+	'IMG_TOPIC_READ_MINE'			=> 'Viestiketju, johon olen vastannut',
 	'IMG_TOPIC_READ_HOT'			=> 'Viestiketju on suosittu',
-	'IMG_TOPIC_READ_HOT_MINE'		=> 'Suosittu viestiketju johon olen vastannut',
+	'IMG_TOPIC_READ_HOT_MINE'		=> 'Suosittu viestiketju, johon olen vastannut',
 	'IMG_TOPIC_READ_LOCKED'			=> 'Viestiketju on lukittu',
 	'IMG_TOPIC_READ_LOCKED_MINE'	=> 'Lukittu viestiketju on lähetetty alueelle',
 
@@ -284,9 +284,9 @@ $lang = array_merge($lang, array(
 	'INSTALLED_STYLE'			=> 'Asennetut tyylit',
 	'INSTALLED_TEMPLATE'		=> 'Asennetut mallineet',
 	'INSTALLED_THEME'			=> 'Asennetut teemat',
-    'KEEP_IMAGESET'             => 'Säilytä “%s” kuvapaketti',
-    'KEEP_TEMPLATE'             => 'Säilytä “%s” malline',
-    'KEEP_THEME'                => 'Säilytä “%s” teema',
+    'KEEP_IMAGESET'             => 'Säilytä kuvapaketti “%s”',
+    'KEEP_TEMPLATE'             => 'Säilytä malline “%s”',
+    'KEEP_THEME'                => 'Säilytä teema “%s”',
 
 	'LINE_SPACING'				=> 'Rivin välistys',
 	'LOCALISED_IMAGES'			=> 'Lokalisoitu',
@@ -309,11 +309,11 @@ $lang = array_merge($lang, array(
 	'ONLY_STYLE'			=> 'Tämä on ainoa jäljellä oleva tyyli. Et voi poistaa sitä',
 	'ONLY_TEMPLATE'			=> 'Tämä on ainoa jäljellä oleva mallinepaketti. Et voi poistaa sitä',
 	'ONLY_THEME'			=> 'Tämä on ainoa jäljellä oleva teema. Et voi poistaa sitä',
-	'OPTIONAL_BASIS'		=> 'vaihtoehtoisuus',
+	'OPTIONAL_BASIS'		=> 'Vaihtoehtoisuus',
 
 	'REFRESH'					=> 'Virkistä',
 	'REPEAT_NO'					=> 'Ei mitään',
-	'REPEAT_X'					=> 'vain vaakatasossa',
+	'REPEAT_X'					=> 'Vain vaakatasossa',
 	'REPEAT_Y'					=> 'Vain pystysuunnassa',
 	'REPEAT_ALL'				=> 'Kumpaankin suuntaan',
 	'REPLACE_IMAGESET'			=> 'Korvaa kuvapaketti tällä',
@@ -325,13 +325,13 @@ $lang = array_merge($lang, array(
 	'REPLACE_THEME'				=> 'Korvaa teema tällä',
 	'REPLACE_THEME_EXPLAIN'		=> 'Tämä teema korvaa poistamasi teeman kaikissa tyyleissä, jotka käyttivät sitä.',
     'REPLACE_WITH_OPTION'       => 'Korvaa käyttämällä “%s”',
-	'REQUIRES_IMAGESET'			=> 'Tämä tyyli vaatii %s kuvapaketin olevan asenenttu.',
-	'REQUIRES_TEMPLATE'			=> 'Tämä tyyli vaatii %s mallinepaketin olevan asennettu.',
-	'REQUIRES_THEME'			=> 'Tämä tyyli vaatii %s teeman olevan asennettu.',
+	'REQUIRES_IMAGESET'			=> 'Tämä tyyli vaatii kuvapaketin %s olevan asenenttu.',
+	'REQUIRES_TEMPLATE'			=> 'Tämä tyyli vaatii mallinepaketin %s olevan asennettu.',
+	'REQUIRES_THEME'			=> 'Tämä tyyli vaatii teeman %s olevan asennettu.',
 
 	'SELECT_IMAGE'				=> 'Valitse kuva',
 	'SELECT_TEMPLATE'			=> 'Valitse mallinetiedosto',
-	'SELECT_THEME'				=> 'valitse teematiedosto',
+	'SELECT_THEME'				=> 'Valitse teematiedosto',
 	'SELECTED_IMAGE'			=> 'Valittu kuva',
 	'SELECTED_IMAGESET'			=> 'Valittu kuvapaketti',
 	'SELECTED_TEMPLATE'			=> 'Valittu malline',
@@ -361,42 +361,42 @@ $lang = array_merge($lang, array(
 	'STYLE_EXPORTED'			=> 'Tyyli on viety onnistuneesti ja tallennettu %s',
 	'STYLE_IMAGESET'			=> 'Kuvapaketti',
 	'STYLE_NAME'				=> 'Tyylin nimi',
-	'STYLE_TEMPLATE'			=> 'malline',
+	'STYLE_TEMPLATE'			=> 'Malline',
 	'STYLE_THEME'				=> 'Teema',
 	'STYLE_USED_BY'				=> 'Käyttäjien lkm',
 
-	'TEMPLATE_ADDED'			=> 'mallinepaketti on lisäty ja tallennettu tiedostojärjestelmään',
-	'TEMPLATE_ADDED_DB'			=> 'mallinepaketti on lisätty ja tallennettu tietokantaan',
-	'TEMPLATE_CACHE'			=> 'mallineen välimuisti',
+	'TEMPLATE_ADDED'			=> 'Mallinepaketti on lisätty ja tallennettu tiedostojärjestelmään.',
+	'TEMPLATE_ADDED_DB'			=> 'Mallinepaketti on lisätty ja tallennettu tietokantaan.',
+	'TEMPLATE_CACHE'			=> 'Mallineen välimuisti',
 	'TEMPLATE_CACHE_EXPLAIN'	=> 'Oletuksena phpBB pitää rakennetun mallineen välimuistissaan. Tämä pienentää palvelimen kuormitusta jokaisella kerralla, kun sivu ladataan ja nopeuttaa siten sivun rakennusaikoja. Täällä voit katsella ja poistaa yksittäisiä tiedostoja tai halutessasi voit tyhjentää välimuistin kokonaan.',
-	'TEMPLATE_CACHE_CLEARED'	=> 'mallineen välimuisti on tyhjennetty',
+	'TEMPLATE_CACHE_CLEARED'	=> 'Mallineen välimuisti on tyhjennetty.',
 	'TEMPLATE_CACHE_EMPTY'		=> 'Välimuistissa ei ole mallineita.',
-	'TEMPLATE_DELETED'			=> 'mallinepaketti on poistettu',
+	'TEMPLATE_DELETED'			=> 'Mallinepaketti on poistettu.',
     'TEMPLATE_DELETE_DEPENDENT'   => 'Tätä tyyliä ei voi poistaa, sillä yksi tai useampi tyyli lainaa siitä komponentteja:',
-	'TEMPLATE_DELETED_FS'		=> 'mallinepaketti on poistettu tietokannasta, mutta joitain tiedostoja saattaa olla vielä tiedostojärjestelmässä',
-	'TEMPLATE_DETAILS_UPDATED'	=> 'mallineen yksityiskohdat on päivitetty',
-	'TEMPLATE_EDITOR'			=> 'Raaka HTML malline editori',
-	'TEMPLATE_EDITOR_HEIGHT'	=> 'malline editorin korkeus',
+	'TEMPLATE_DELETED_FS'		=> 'Mallinepaketti on poistettu tietokannasta, mutta joitain tiedostoja saattaa olla vielä tiedostojärjestelmässä.',
+	'TEMPLATE_DETAILS_UPDATED'	=> 'Mallineen yksityiskohdat on päivitetty',
+	'TEMPLATE_EDITOR'			=> 'Raaka HTML-malline-editori',
+	'TEMPLATE_EDITOR_HEIGHT'	=> 'Malline-editorin korkeus',
 	'TEMPLATE_ERR_ARCHIVE'		=> 'Ole hyvä ja valitse arkistointi metodi',
 	'TEMPLATE_ERR_CACHE_READ'	=> 'Välimuistin käyttämää hakemistoa ei voitu avata.',
 	'TEMPLATE_ERR_COPY_LONG'	=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
 	'TEMPLATE_ERR_NAME_CHARS'	=> 'mallineen nimi voi koostua vain kirjaimista, numeroista, -, +, _ ja välilyönneistä',
 	'TEMPLATE_ERR_NAME_EXIST'	=> 'Tämän niminen mallinepaketti on jo olemassa',
-	'TEMPLATE_ERR_NAME_LONG'	=> 'mallineen nimi ei voi olla 30 merkkiää pidempi',
+	'TEMPLATE_ERR_NAME_LONG'	=> 'Mallineen nimi ei voi olla 30 merkkiä pidempi.',
 	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Määrittämässäsi arkistossa ei ole kelvollista mallinepakettia.',
-    'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'Tämä tyyli tarvitsee %s -tyylin asennuksen, eikä voi lainata itseltään. ',
+    'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'Tämä tyyli tarvitsee %s -tyylin asennuksen, eikä voi lainata itseltään.',
 	'TEMPLATE_ERR_STYLE_NAME'	=> 'Anna nimi tälle mallineelle',
 	'TEMPLATE_EXPORT'			=> 'Vie mallineita',
-	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Täällä voit viedä mallinepaketin arkistoon. Tämä arkisto pitää sisällään kaiken tarvittavan tiedon, jotta sen voi asentaa toiselle keskustelufoorumille. Voit vlita lataatko tiedoston omalle koneellesi tai tallentaa sen store-hakemistoon myöhmpää käyttöä varten.',
-	'TEMPLATE_EXPORTED'			=> 'mallineet on viety onnistuneesti ja tallennettu %s',
-	'TEMPLATE_FILE'				=> 'malline tiedosto',
-	'TEMPLATE_FILE_UPDATED'		=> 'malline tiedosto on päivitetty.',
+	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Täällä voit viedä mallinepaketin arkistoon. Tämä arkisto pitää sisällään kaiken tarvittavan tiedon, jotta sen voi asentaa toiselle keskustelufoorumille. Voit valita lataatko tiedoston omalle koneellesi vai tallennatko sen store-hakemistoon myöhmpää käyttöä varten.',
+	'TEMPLATE_EXPORTED'			=> 'Mallineet on viety onnistuneesti ja tallennettu %s',
+	'TEMPLATE_FILE'				=> 'Mallinetiedosto',
+	'TEMPLATE_FILE_UPDATED'		=> 'Mallinetiedosto on päivitetty.',
     'TEMPLATE_INHERITS'         => 'Tämä tyyli lainaa komponentteja tyylistä %s ja sen vuoksi sitä ei voi tallentaa eri menetelmällä, kuin se mistä lainaukset suoritetaan.',
 	'TEMPLATE_LOCATION'			=> 'Tallenna mallineet',
 	'TEMPLATE_LOCATION_EXPLAIN'	=> 'Kuvat tallennetaan aina tiedostojärjestelmään.',
-	'TEMPLATE_NAME'				=> 'mallineen nimi',
+	'TEMPLATE_NAME'				=> 'Mallineen nimi',
 	'TEMPLATE_FILE_NOT_WRITABLE'=> 'Mallinetiedoston %s kirjoitus epäonnistui. Ole hyvä ja tarkista hakemiston ja tiedoston oikeudet.',
-	'TEMPLATE_REFRESHED'		=> 'malline on virkistetty',
+	'TEMPLATE_REFRESHED'		=> 'Malline on virkistetty.',
 
 	'THEME_ADDED'				=> 'Uusi teema lisätty tiedostojärjestelmään',
 	'THEME_ADDED_DB'			=> 'Uusi teema lisätty tietokantaan',
@@ -404,9 +404,9 @@ $lang = array_merge($lang, array(
 	'THEME_DELETED'				=> 'Teema on poistettu',
 	'THEME_DELETED_FS'			=> 'Teema on poistettu tietokannasta, mutta joitain tiedostoja on vielä tiedostojärjestelmässä',
 	'THEME_DETAILS_UPDATED'		=> 'Teeman yksityiskohdat ovat päivitetty',
-	'THEME_EDITOR'				=> 'Raaka CSS teema editori',
+	'THEME_EDITOR'				=> 'Raaka CSS-teemaeditori',
 	'THEME_EDITOR_HEIGHT'		=> 'Teema editorin korkeus',
-	'THEME_ERR_ARCHIVE'			=> 'Ole hyvä ja valitse arkistointi metodi',
+	'THEME_ERR_ARCHIVE'			=> 'Ole hyvä ja valitse arkistointitapa',
 	'THEME_ERR_CLASS_CHARS'		=> 'Vain kirjaimet, numerot ja ., :, - ja # on sallittu luokkien nimissä.',
 	'THEME_ERR_COPY_LONG'		=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
 	'THEME_ERR_NAME_CHARS'		=> 'Teeman nimessä voi olla vain kirjaimia, numeroita, -, +, _ ja välilyöntejä',
@@ -415,9 +415,9 @@ $lang = array_merge($lang, array(
 	'THEME_ERR_NOT_THEME'		=> 'Määrittämässäsi arkistossa ei ole kelvollista teemaa.',
 	'THEME_ERR_REFRESH_FS'		=> 'Tämä teema on tiedostojärjestelmässä, joten sitä ei tarvitse virkistää.',
 	'THEME_ERR_STYLE_NAME'		=> 'Sinun täytyy antaa nimi tälle teemalle',
-	'THEME_FILE'				=> 'Teema tiedosto',
+	'THEME_FILE'				=> 'Teematiedosto',
 	'THEME_EXPORT'				=> 'Vie teema',
-	'THEME_EXPORT_EXPLAIN'		=> 'Täällä voit viedä teeman arkistoon. Tämä arkisto pitää sisällään kaiken tarvittavan tiedon, jotta sen voi asentaa toiselle keskustelufoorumille. Voit vlita lataatko tiedoston omalle koneellesi tai tallentaa sen store-hakemistoon myöhmpää käyttöä varten.',
+	'THEME_EXPORT_EXPLAIN'		=> 'Täällä voit viedä teeman arkistoon. Tämä arkisto pitää sisällään kaiken tarvittavan tiedon, jotta sen voi asentaa toiselle keskustelufoorumille. Voit valita lataatko tiedoston omalle koneellesi vai tallennatko sen store-hakemistoon myöhmpää käyttöä varten.',
 	'THEME_EXPORTED'			=> 'Teema on viety onnistuneesti ja tallennettu %s',
 	'THEME_LOCATION'			=> 'Tallenna tyylitiedosto',
 	'THEME_LOCATION_EXPLAIN'	=> 'Kuvat tallennetaan aina tiedostojärjestelmään.',
