@@ -87,11 +87,11 @@ $lang = array_merge($lang, array(
 	'AVATAR_NO_SIZE'				=> 'En onnistunut lukemaan linkitetyn avatarin korkeutta ja leveyttä. Ole hyvä ja lisää ne manuaalisesti.',
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Tiedosto siirrettiin vain osittain',
 	'AVATAR_PHP_SIZE_NA'			=> 'Avatar-tiedoston koko on liian suuri.<br />En voinut päätellä maksimikokoa, jonka PHP on määritellyt php.ini-tiedostossa.',
-	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Avatar-tiedoston koko on liian suuri. Maksimi sallittu koko on %1$d %2$s.<br />Huomaa, että tämä asetetaan php.ini-tiedostossa ja sitä ei voi ohittaa.',
+	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Avatar-tiedoston koko on liian suuri. Suurin sallittu koko on %1$d %2$s.<br />Huomaa, että tämä asetetaan php.ini-tiedostossa ja sitä ei voi ohittaa.',
 	'AVATAR_URL_INVALID'			=> 'Antamasi linkki on epäkelpo.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Tiedostoa ei löydy.',
 	'AVATAR_WRONG_FILESIZE'			=> 'Avatar-tiedoston koko täytyy olla välilä 0 ja %1d %2s.',
-	'AVATAR_WRONG_SIZE'				=> 'Avatarin täytyy olla vähintään %1$d pikseliä leveä, %2$d pikseliä korkea ja maksimissaan %3$d pikseliä leveä ja %4$d pikseliä korkea. Lähettämäsi avatar on %5$d pikseliä leveä ja %6$d korkeus pikseliä.',
+	'AVATAR_WRONG_SIZE'				=> 'Avatarin täytyy olla vähintään %1$d kuvapistettä leveä, %2$d kuvapistettä korkea ja enimmillään %3$d kuvapistettä leveä ja %4$d kuvapistettä korkea. Lähettämäsi avatar on %5$d kuvapistettä leveä ja %6$d kuvapistettä korkea.',
 
 	'BACK_TO_TOP'			=> 'Ylös',
 	'BACK_TO_PREV'			=> 'Takaisin edelliselle sivulle',
@@ -161,7 +161,7 @@ $lang = array_merge($lang, array(
 	'EMAIL'								=> 'Sähköposti',
 	'EMAIL_ADDRESS'						=> 'Sähköposti',
 	'EMAIL_INVALID_EMAIL'				=> 'Antamasi sähköpostiosoite on epäkelpo.',
-	'EMAIL_SMTP_ERROR_RESPONSE'			=> "Sähköpostin lähettämisessä tapahtui virhe <strong>Rivi %s</strong>. Vastaus: %s",
+	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'Sähköpostin lähettämisessä tapahtui virhe <strong>rivillä %1$s</strong>. Vastaus: %2$s',
 	'EMPTY_SUBJECT'						=> 'Sinun täytyy antaa otsikko aloittaessasi uutta ketjua.',
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Sinun täytyy antaa aihe kirjoittaessasi uutta viestiä.',
 	'ENABLED'							=> 'Päällä',
@@ -201,7 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES'			=> 'Alueen säännöt',
 	'FORUM_RULES_LINK'		=> 'Paina linkkiä nähdäksesi säännöt',
 	'FROM'					=> 'Lähettäjä',
-	'FSOCK_DISABLED'		=> 'Operaatiota ei voitu suorittaa loppuun koska <var>fsockopen</var> -funktiot ovat poissa käytöstä tai pyydettyä palvelinta ei löytynyt.',
+	'FSOCK_DISABLED'		=> 'Operaatiota ei voitu suorittaa loppuun, koska <var>fsockopen</var>-funktio on poissa käytöstä tai pyydettyä palvelinta ei löytynyt.',
 	'FSOCK_TIMEOUT'			=> 'Verkossa tapahtui aikakatkaisu luettaessa.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-palvelin',
@@ -251,7 +251,7 @@ $lang = array_merge($lang, array(
 	'G_BOTS'					=> 'Botit',
 	'G_GUESTS'					=> 'Vierailijat',
 	'G_REGISTERED'				=> 'Rekisteröityneet käyttäjät',
-	'G_REGISTERED_COPPA'		=> 'Rekisteröidyt COPPA käyttäjät',
+	'G_REGISTERED_COPPA'		=> 'Rekisteröidyt COPPA-käyttäjät',
 	'G_GLOBAL_MODERATORS'		=> 'Valvojat',
 	'G_NEWLY_REGISTERED'		=> 'Uudet käyttäjät',
 
@@ -274,7 +274,7 @@ $lang = array_merge($lang, array(
 	'IF'						=> 'jos',
 	'IMAGE'						=> 'Kuva',
 	'IMAGE_FILETYPE_INVALID'	=> 'Tätä kuvan tyyppiä %d mimetyypille %s ei ole tuettu.',
-	'IMAGE_FILETYPE_MISMATCH'	=> 'Kuvatyyppi ei täsmää: Odotettiin tunnistetta %1$s, mutta annettiin %2$s.',
+	'IMAGE_FILETYPE_MISMATCH'	=> 'Kuvatyyppi ei täsmää: odotettiin tunnistetta %1$s, mutta annettiin %2$s.',
 	'IN'						=> 'Sijainti:',
 	'INDEX'						=> 'Etusivu',
 	'INFORMATION'				=> 'Informaatio',
@@ -297,8 +297,8 @@ $lang = array_merge($lang, array(
 	'LAST_UPDATED'						=> 'Viimeksi päivitetty',
 	'LAST_VISIT'						=> 'Viimeksi vieraillut',
 	'LDAP_NO_LDAP_EXTENSION'			=> 'LDAP ei ole saatavilla',
-	'LDAP_NO_SERVER_CONNECTION'			=> 'En saanut yhteyttä LDAP palvelimeen',
-    'LDAP_SEARCH_FAILED'                => 'LDAP hakemiston etsinnässä tapahtui virhe.',
+	'LDAP_NO_SERVER_CONNECTION'			=> 'En saanut yhteyttä LDAP-palvelimeen',
+    'LDAP_SEARCH_FAILED'                => 'LDAP-hakemiston etsinnässä tapahtui virhe.',
 	'LEGEND'							=> 'Selite',
 	'LOCATION'							=> 'Paikkakunta',
 	'LOCK_POST'							=> 'Lukitse viesti',
@@ -307,13 +307,13 @@ $lang = array_merge($lang, array(
 	'LOGIN'								=> 'Kirjaudu sisään',
 	'LOGIN_CHECK_PM'					=> 'Kirjaudu sisään tarkistaaksesi yksityisviestit',
 	'LOGIN_CONFIRMATION'				=> 'kirjautumisen vahvistus',
-	'LOGIN_CONFIRM_EXPLAIN'				=> 'Estääkseen käyttäjätunnusten murtamista sivuston ylläpitäjät pyytävät sinua täyttämään varmistuskoodin käytettyäsi maksimimäärän kirjautumisyrityksiä. Koodi näkyy kuvassa, jonka pitäisi näkyä alapuolella. Mikäli olet heikkonäköinen tai et muuten saa koodista selvää, ota yhteyttä keskustelufoorumin %sYlläpitäjiin%s.', // Ei käytössä
-    'LOGIN_ERROR_ATTEMPTS'              => 'Olet yrittänyt kirjautua sisään liian monta kertaa. Ole hyvä ja syötä myös varmistuskoodi',
+	'LOGIN_CONFIRM_EXPLAIN'				=> 'Estääkseen käyttäjätunnusten murtamista sivuston ylläpitäjät pyytävät sinua täyttämään varmistuskoodin käytettyäsi maksimimäärän kirjautumisyrityksiä. Koodi näkyy kuvassa, jonka pitäisi näkyä alapuolella. Mikäli olet heikkonäköinen tai et muuten saa koodista selvää, ota yhteyttä keskustelufoorumin %sylläpitäjiin%s.', // Ei käytössä
+    'LOGIN_ERROR_ATTEMPTS'              => 'Olet yrittänyt kirjautua sisään liian monta kertaa. Ole hyvä ja syötä myös varmistuskoodi.',
 	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Apache ei ole tunnistanut sinua.',
 	'LOGIN_ERROR_PASSWORD'				=> 'Olet antanut väärän salasanan. Ole hyvä ja tarkista salasanasi. Yritä sen jälkeen uudestaan. Mikäli ongelmat jatkuvat, ota yhteyttä sivuston %sylläpitäjiin%s.',
-	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Salasanasi konvertoiminen epäonnistui tätä keskustelufoorumia päivitettäessä. Ole hyvä %sja pyydä uutta salasanaa%s. Mikäli ongelmat jatkuvat. Ota yhteyttä %sylläpitäjiin%s.',
+	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Salasanasi muuntaminen epäonnistui tätä keskustelufoorumia päivitettäessä. Ole hyvä %sja pyydä uutta salasanaa%s. Mikäli ongelmat jatkuvat, ota yhteyttä %sylläpitäjiin%s.',
 	'LOGIN_ERROR_USERNAME'				=> 'Olet antanut väärän käyttäjätunnuksen. Ole hyvä ja tarkista tunnuksesi. Yritä sen jälkeen uudestaan. Mikäli ongelmat jatkuvat, ota yhteyttä sivuston %sylläpitäjiin%s.',
-	'LOGIN_FORUM'						=> 'Anna salasana katsoaksesi- tai lähettääksesi viestejä tällä alueella.',
+	'LOGIN_FORUM'						=> 'Anna salasana katsoaksesi tai lähettääksesi viestejä tällä alueella.',
 	'LOGIN_INFO'						=> 'Sinun tulee olla rekisteröitynyt voidaksesi kirjautua sisään. Rekisteröityminen vie vain hetken, mutta antaa sinulle lisää mahdollisuuksia. Sivuston ylläpitäjä voi myös antaa erityisoikeuksia rekisteröityneille käyttäjille. Muista lukea käyttöehtomme ja siihen liittyvät käytännöt ennen kirjautumista. Muista myös lukea keskustelufoorumin säännöt.',
 	'LOGIN_VIEWFORUM'					=> 'Sinun tulee olla rekisteröitynyt käyttäjä ja kirjautunut sisään nähdäksesi tämän alueen.',
 	'LOGIN_EXPLAIN_EDIT'				=> 'Sinun tulee olla rekisteröitynyt käyttäjä ja kirjautunut sisään muokataksesi viestejä tällä alueella.',
@@ -369,7 +369,7 @@ $lang = array_merge($lang, array(
 	'NO_AUTH_ADMIN'				=> 'Sinulla ei ole ylläpitäjän oikeuksia, joten et voi muokata ylläpidon asetuksia.',
 	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Et voi tunnistautua toisena käyttäjänä.',
 	'NO_AUTH_OPERATION'			=> 'Käyttö-oikeutesi eivät riitä tämän toiminnon suorittamiseen.',
-	'NO_CONNECT_TO_SMTP_HOST'	=> 'En saanut yhteyttä smtp-palvelimeen : %s : %s',
+	'NO_CONNECT_TO_SMTP_HOST'	=> 'En saanut yhteyttä SMTP-palvelimeen : %s : %s',
 	'NO_BIRTHDAYS'				=> 'Ei syntymäpäiviä tänään',
 	'NO_EMAIL_MESSAGE'			=> 'Sähköpostin viesti oli tyhjä',
 	'NO_EMAIL_RESPONSE_CODE'	=> 'En saanut sähköpostipalvelimen vastauskoodeja',
@@ -426,9 +426,9 @@ $lang = array_merge($lang, array(
 	'PAGE_OF'				=> 'Sivu <strong>%1$d</strong>/<strong>%2$d</strong>',
 	'PASSWORD'				=> 'Salasana',
 	'PIXEL'					=> 'px',
-	'PLAY_QUICKTIME_FILE'	=> 'Toista quicktime-tiedosto',
+	'PLAY_QUICKTIME_FILE'	=> 'Toista Quicktime-tiedosto',
 	'PM'					=> 'Yksityisviesti',
-    'PM_REPORTED'           => 'Klikkaa nähdäksesi ilmoituksen',
+    'PM_REPORTED'           => 'Napsauta nähdäksesi ilmoituksen',
 	'POSTING_MESSAGE'		=> 'Kirjoittaa viestiä alueella %s',
 	'POSTING_PRIVATE_MESSAGE'	=> 'Kirjoittaa yksityisviestiä',
 	'POST'					=> 'Viesti',
@@ -505,8 +505,8 @@ $lang = array_merge($lang, array(
 	'FEED_NEWS'					=> 'Uutiset',
 	'FEED_TOPICS_ACTIVE'		=> 'Aktiiviset viestiketjut',
 	'FEED_TOPICS_NEW'			=> 'Uudet viestiketjut',
-	'RULES_ATTACH_CAN'			=> '<strong>Voit</strong> lähettää liitetiedostoja.',
-	'RULES_ATTACH_CANNOT'		=> '<strong>Et voi</strong> lähettää liitetiedostoja.',
+	'RULES_ATTACH_CAN'			=> '<strong>Voit</strong> lähettää liitetiedostoja',
+	'RULES_ATTACH_CANNOT'		=> '<strong>Et voi</strong> lähettää liitetiedostoja',
 	'RULES_DELETE_CAN'			=> '<strong>Voit</strong> poistaa omat viestisi',
 	'RULES_DELETE_CANNOT'		=> '<strong>Et voi</strong> poistaa omia viestejäsi',
 	'RULES_DOWNLOAD_CAN'		=> '<strong>Voit</strong> ladata liitetiedostoja',
@@ -560,7 +560,7 @@ $lang = array_merge($lang, array(
 	'SORT_TOPIC_TITLE'			=> 'Viestin otsikko',
 	'SORT_USERNAME'				=> 'käyttäjätunnus',
 	'SPLIT_TOPIC'				=> 'Jaa viestiketju',
-	'SQL_ERROR_OCCURRED'		=> 'Tapahtui SQL virhe tätä sivua noudettaessa. ole hyvä ja ota yhteyttä %sKeskustelufoorumin ylläpitäjiin%s mikäli tämä ongelma jatkuu.',
+	'SQL_ERROR_OCCURRED'		=> 'Tapahtui SQL-virhe tätä sivua noudettaessa. Ole hyvä ja ota yhteyttä %skeskustelufoorumin ylläpitäjiin%s mikäli tämä ongelma jatkuu.',
 	'STATISTICS'				=> 'Tilastot',
 	'START_WATCHING_FORUM'		=> 'Seuraa aluetta',
 	'START_WATCHING_TOPIC'		=> 'Seuraa vastauksia',
@@ -584,11 +584,11 @@ $lang = array_merge($lang, array(
 	'TOO_LONG_AIM'					=> 'Antamasi näyttönimi on liian pitkä.',
 	'TOO_LONG_CONFIRM_CODE'			=> 'Antamasi varmistuskoodi on liian pitkä.',
 	'TOO_LONG_DATEFORMAT'			=> 'Antamasi päiväyksen muoto on liian pitkä.',
-	'TOO_LONG_ICQ'					=> 'Antamasi ICQ numero on liian pitkä.',
+	'TOO_LONG_ICQ'					=> 'Antamasi ICQ-numero on liian pitkä.',
 	'TOO_LONG_INTERESTS'			=> 'Antamasi mielenkiinnon kohde on liian pitkä.',
-	'TOO_LONG_JABBER'				=> 'Antamasi Jabber tilin nimi on liian pitkä.',
+	'TOO_LONG_JABBER'				=> 'Antamasi Jabber-tilin nimi on liian pitkä.',
 	'TOO_LONG_LOCATION'				=> 'Antamasi paikannimi on liian pitkä.',
-	'TOO_LONG_MSN'					=> 'Antamasi MSN nimi on liian pitkä.',
+	'TOO_LONG_MSN'					=> 'Antamasi MSN-nimi on liian pitkä.',
 	'TOO_LONG_NEW_PASSWORD'			=> 'Antamasi salasana on liian pitkä.',
 	'TOO_LONG_OCCUPATION'			=> 'Antamasi ammatti on liian pitkä.',
 	'TOO_LONG_PASSWORD_CONFIRM'		=> 'Antamasi salasanan vahvistus on liian pitkä.',
@@ -597,7 +597,7 @@ $lang = array_merge($lang, array(
 	'TOO_LONG_EMAIL'				=> 'Antamasi sähköpostiosoite on liian pitkä.',
 	'TOO_LONG_EMAIL_CONFIRM'		=> 'Antamasi sähköpostin varmistus on liian pitkä.',
 	'TOO_LONG_WEBSITE'				=> 'Antamasi nettisivun osoite on liian pitkä.',
-	'TOO_LONG_YIM'					=> 'Antamasi yahoo messenger nimi on liian pitkä.',
+	'TOO_LONG_YIM'					=> 'Antamasi Yahoo! Messenger -nimi on liian pitkä.',
 
 	'TOO_MANY_VOTE_OPTIONS'			=> 'Olet yrittänyt äänestää liian montaa vaihtoehtoa.',
     'TOO_SHORT'                  	=> 'Antamasi arvo on liian lyhyt.',
@@ -605,11 +605,11 @@ $lang = array_merge($lang, array(
 	'TOO_SHORT_AIM'					=> 'Antamasi näyttönimi on liian lyhyt.',
 	'TOO_SHORT_CONFIRM_CODE'		=> 'Antamasi varmistuskoodi on liian lyhyt.',
 	'TOO_SHORT_DATEFORMAT'			=> 'Antamasi päiväyksen muoto on liian lyhyt.',
-	'TOO_SHORT_ICQ'					=> 'Antamasi ICQ numero on liian lyhyt.',
+	'TOO_SHORT_ICQ'					=> 'Antamasi ICQ-numero on liian lyhyt.',
 	'TOO_SHORT_INTERESTS'			=> 'Antamasi mielenkiinnon kohde on liian lyhyt.',
-	'TOO_SHORT_JABBER'				=> 'Antamasi Jabber tilin nimi on liian lyhyt.',
+	'TOO_SHORT_JABBER'				=> 'Antamasi Jabber-tilin nimi on liian lyhyt.',
 	'TOO_SHORT_LOCATION'			=> 'Antamasi sijainti on liian lyhyt.',
-	'TOO_SHORT_MSN'					=> 'Antamasi MSN nimi on liian lyhyt.',
+	'TOO_SHORT_MSN'					=> 'Antamasi MSN-nimi on liian lyhyt.',
 	'TOO_SHORT_NEW_PASSWORD'		=> 'Antamasi salasana on liian lyhyt.',
 	'TOO_SHORT_OCCUPATION'			=> 'Antamasi ammatti on liian lyhyt.',
 	'TOO_SHORT_PASSWORD_CONFIRM'	=> 'Antamasi salasanan vahvistus on liian lyhyt.',
@@ -618,9 +618,9 @@ $lang = array_merge($lang, array(
 	'TOO_SHORT_EMAIL'				=> 'Antamasi sähköpostiosoite on liian lyhyt.',
 	'TOO_SHORT_EMAIL_CONFIRM'		=> 'Antamasi sähköpostiosoitteen varmistus on liian lyhyt.',
 	'TOO_SHORT_WEBSITE'				=> 'Antamasi nettisivun osoite on liian lyhyt.',
-	'TOO_SHORT_YIM'					=> 'Antamasi yahoo messenger nimi on liian lyhyt.',
+	'TOO_SHORT_YIM'					=> 'Antamasi Yahoo! Messenger -nimi on liian lyhyt.',
     'TOO_SMALL'                     => 'Antamasi arvo on liian pieni.',
-    'TOO_SMALL_MAX_RECIPIENTS'      => 'Maksimi arvo <strong>yksityisviestien vastaanottajamäärälle</strong> on liian pieni.',
+	'TOO_SMALL_MAX_RECIPIENTS'      => 'Enimmäisarvo <strong>yksityisviestien vastaanottajamäärälle</strong> on liian pieni.',
 
 	'TOPIC'				=> 'Aihe',
 	'TOPICS'			=> 'Aiheet',
@@ -646,14 +646,14 @@ $lang = array_merge($lang, array(
 	'TOTAL_TOPICS_ZERO'	=> 'Viestiketjuja on yhteensä <strong>0</strong> kappaletta',
 	'TOTAL_USERS_OTHER'	=> 'Käyttäjiä yhteensä <strong>%d</strong>',
 	'TOTAL_USERS_ZERO'	=> 'Käyttäjiä on yhteensä <strong>0</strong> kappaletta',
-	'TRACKED_PHP_ERROR'	=> 'Seuratut PHP virheet: %s',
+	'TRACKED_PHP_ERROR'	=> 'Seuratut PHP-virheet: %s',
 
 	'UNABLE_GET_IMAGE_SIZE'	=> 'Kuvan koon määritteleminen ei onnistunut.',
 	'UNABLE_TO_DELIVER_FILE'=> 'Tiedoston toimittaminen ei onnistu.',
 	'UNKNOWN_BROWSER'		=> 'Tunnistamaton selain',
 	'UNMARK_ALL'			=> 'Poista valinnat',
 	'UNREAD_MESSAGES'		=> 'Lukemattomat viestit',
-	'UNREAD_PM'				=> '<strong>%d</strong> Lukematon viesti',
+	'UNREAD_PM'				=> '<strong>%d</strong> lukematon viesti',
 	'UNREAD_PMS'			=> '<strong>%d</strong> lukemattomia viestejä',
     'UNREAD_POST'           => 'Lukematon viesti',
     'UNREAD_POSTS'          => 'Lukemattomat viestit',
@@ -666,7 +666,7 @@ $lang = array_merge($lang, array(
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Et enää seuraa valitsemiasi merkintöjä.',
 	'UPDATE'				=> 'Päivitä',
 	'UPLOAD_IN_PROGRESS'	=> 'Siirto käynnissä',
-	'URL_REDIRECT'			=> 'Mikäli selaimesi ei tue meta-uudelleenohjausta paina %sTÄHÄN%s jatkaaksesi eteenpäin.',
+	'URL_REDIRECT'			=> 'Mikäli selaimesi ei tue meta-uudelleenohjausta, napsauta %sTÄSTÄ%s jatkaaksesi eteenpäin.',
 	'USERGROUPS'			=> 'Ryhmät',
 	'USERNAME'				=> 'Käyttäjätunnus',
 	'USERNAMES'				=> 'Käyttäjätunnukset',
@@ -680,7 +680,7 @@ $lang = array_merge($lang, array(
 
 	'VARIANT_DATE_SEPARATOR'	=> ' / ',	// Used in date format dropdown, eg: "Today, 13:37 / 01 Jan 2007, 13:37" ... to join a relative date with calendar date
 	'VIEWED'					=> 'Katselee',
-	'VIEWING_FAQ'				=> 'Lukee Ohjeita yleisimpiin kysymyksiin',
+	'VIEWING_FAQ'				=> 'Lukee vastauksia yleisimpiin kysymyksiin',
 	'VIEWING_MEMBERS'			=> 'Katselee käyttäjiä',
 	'VIEWING_ONLINE'			=> 'Katselee listaa paikallaolijoista',
 	'VIEWING_MCP'				=> 'Käyttää valvojien hallintapaneelia',
@@ -693,7 +693,7 @@ $lang = array_merge($lang, array(
 	'VIEW_FORUM_LOGS'			=> 'Näytä lokitiedot',
 	'VIEW_LATEST_POST'			=> 'Näytä uusin viesti',
 	'VIEW_NEWEST_POST'			=> 'Näytä ensimmäinen lukematon viesti',
-	'VIEW_NOTES'				=> 'Näytä Muistiinpanot',
+	'VIEW_NOTES'				=> 'Näytä muistiinpanot',
 	'VIEW_ONLINE_TIME'			=> 'Tieto perustuu viimeisen %d minuutin aikana olleisiin aktiivisiin käyttäjiin',
 	'VIEW_ONLINE_TIMES'			=> 'Tieto perustuu viimeisen %d minuutin aikana olleisiin aktiivisiin käyttäjiin',
 	'VIEW_TOPIC'				=> 'katso viestiketjua',
@@ -717,20 +717,20 @@ $lang = array_merge($lang, array(
 	'WHOIS'				=> 'Whois',
 	'WHO_IS_ONLINE'		=> 'Paikallaolijat',
 	'WRONG_PASSWORD'	=> 'Annoit väärän salasanan.',
-	'WRONG_DATA_COLOUR'			=> 'The colour value you entered is invalid.',
+	'WRONG_DATA_COLOUR'			=> 'Antamasi väriarvo ei kelpaa.',
 
-	'WRONG_DATA_ICQ'			=> 'Antamasi numero ei ole kelvollinen ICQ numero.',
-	'WRONG_DATA_JABBER'			=> 'Antamasi nimi ei ole kelvollinen Jabber tilin nimi.',
+	'WRONG_DATA_ICQ'			=> 'Antamasi numero ei ole kelvollinen ICQ-numero.',
+	'WRONG_DATA_JABBER'			=> 'Antamasi nimi ei ole kelvollinen Jabber-tilin nimi.',
 	'WRONG_DATA_LANG'			=> 'Antamasi kieli ei ole kelvollinen.',
 	'WRONG_DATA_WEBSITE'		=> 'Antamasi sivun osoitteen täytyy olla täydellinen, mukaanluettuna protokolla. Esimerkiksi http://www.esimerkki.com/.',
 	'WROTE'						=> 'kirjoitti',
 
 	'YEAR'				=> 'Vuosi',
-	'YEAR_MONTH_DAY'	=> '(YYYY-MM-DD)',
+	'YEAR_MONTH_DAY'	=> '(VVVV-KK-PP)',
 	'YES'				=> 'Kyllä',
 	'YIM'				=> 'YIM',
 	'YOU_LAST_VISIT'	=> 'Viimeisin vierailu: %s',
-	'YOU_NEW_PM'		=> 'saapuneet-kansiossa on yksi uusi yksityisviesti',
+	'YOU_NEW_PM'		=> 'Saapuneet-kansiossa on yksi uusi yksityisviesti',
 	'YOU_NEW_PMS'		=> 'Saapuneet-kansiossa on uusia yksityisviestejä',
 	'YOU_NO_NEW_PM'		=> 'Ei uusia yksityisviestejä',
 
@@ -833,46 +833,46 @@ $lang = array_merge($lang, array(
 	),
 
 	'tz_zones'	=> array(
-		'-12'	=> '[UTC - 12] Baker Island Aika',
-		'-11'	=> '[UTC - 11] Niue Time, Samoa Standard Aika',
-		'-10'	=> '[UTC - 10] Hawaii-Aleutian Standard Time, Cook Island Aika',
-		'-9.5'	=> '[UTC - 9:30] Marquesas Islands Aika',
-		'-9'	=> '[UTC - 9] Alaska Standard Time, Gambier Island Aika',
-		'-8'	=> '[UTC - 8] Pacific Standard Aika',
-		'-7'	=> '[UTC - 7] Mountain Standard Aika',
-		'-6'	=> '[UTC - 6] Central Standard Aika',
-		'-5'	=> '[UTC - 5] Eastern Standard Aika',
-        '-4.5'   => '[UTC - 4:30] Venezuelan Standard Aika',
-		'-4'	=> '[UTC - 4] Atlantic Standard Aika',
-		'-3.5'	=> '[UTC - 3:30] Newfoundland Standard Aika',
-		'-3'	=> '[UTC - 3] Amazon Standard Time, Central Greenland Aika',
-		'-2'	=> '[UTC - 2] Fernando de Noronha Time, South Georgia &amp; the South Sandwich Islands Aika',
-		'-1'	=> '[UTC - 1] Azores Standard Time, Cape Verde Time, Eastern Greenland Aika',
-		'0'		=> '[UTC] Western European Time, Greenwich Mean Aika',
-		'1'		=> '[UTC + 1] Central European Time, West African Aika',
-		'2'		=> '[UTC + 2] Eastern European Time, Central African Aika',
-		'3'		=> '[UTC + 3] Moscow Standard Time, Eastern African Aika',
-		'3.5'	=> '[UTC + 3:30] Iran Standard Aika',
-		'4'		=> '[UTC + 4] Gulf Standard Time, Samara Standard Aika',
-		'4.5'	=> '[UTC + 4:30] Afghanistan Aika',
-		'5'		=> '[UTC + 5] Pakistan Standard Time, Yekaterinburg Standard Aika',
-		'5.5'	=> '[UTC + 5:30] Indian Standard Time, Sri Lanka Aika',
-		'5.75'	=> '[UTC + 5:45] Nepal Aika',
-		'6'		=> '[UTC + 6] Bangladesh Time, Bhutan Time, Novosibirsk Standard Aika',
-		'6.5'	=> '[UTC + 6:30] Cocos Islands Time, Myanmar Aika',
-		'7'		=> '[UTC + 7] Indochina Time, Krasnoyarsk Standard Aika',
-		'8'		=> '[UTC + 8] Chinese Standard Time, Australian Western Standard Time, Irkutsk Standard Aika',
-		'8.75'	=> '[UTC + 8:45] Southeastern Western Australia Standard Aika',
-		'9'		=> '[UTC + 9] Japan Standard Time, Korea Standard Time, Chita Standard Aika',
-		'9.5'	=> '[UTC + 9:30] Australian Central Standard Aika',
-		'10'	=> '[UTC + 10] Australian Eastern Standard Time, Vladivostok Standard Aika',
-		'10.5'	=> '[UTC + 10:30] Lord Howe Standard Aika',
-		'11'	=> '[UTC + 11] Solomon Island Time, Magadan Standard Aika',
-		'11.5'	=> '[UTC + 11:30] Norfolk Island Aika',
-		'12'	=> '[UTC + 12] New Zealand Time, Fiji Time, Kamchatka Standard Aika',
-		'12.75'	=> '[UTC + 12:45] Chatham Islands Aika',
-		'13'	=> '[UTC + 13] Tonga Time, Phoenix Islands Aika',
-		'14'	=> '[UTC + 14] Line Island Aika',
+		'-12'	=> '[UTC - 12] Bakersaarten aika',
+		'-11'	=> '[UTC - 11] Niuen aika, Samoan normaaliaika',
+		'-10'	=> '[UTC - 10] Havaijin-Aleuttien normaaliaika, Cooksaarten aika',
+		'-9.5'	=> '[UTC - 9:30] Marquesassaarten aika',
+		'-9'	=> '[UTC - 9] Alaskan normaaliaika, Gambiersaarten aika',
+		'-8'	=> '[UTC - 8] Tyynenmeren normaaliaika',
+		'-7'	=> '[UTC - 7] Kalliovuorten normaaliaika',
+		'-6'	=> '[UTC - 6] Keskinen normaaliaika',
+		'-5'	=> '[UTC - 5] Itäinen normaaliaika',
+        '-4.5'   => '[UTC - 4:30] Venezuelan normaaliaika',
+		'-4'	=> '[UTC - 4] Atlantin normaaliaika',
+		'-3.5'	=> '[UTC - 3:30] Newfoundlandin normaaliaika',
+		'-3'	=> '[UTC - 3] Amazonin normaaliaika, Keski-Grönlannin aika',
+		'-2'	=> '[UTC - 2] Fernando de Noronhan aika, Etelä-Georgian ja Eteläisten Sandwichsaarten aika',
+		'-1'	=> '[UTC - 1] Azorien normaaliaika, Kap Verden aika, Itä-Grönlannin aika',
+		'0'		=> '[UTC] Länsi-Euroopan aika, Greenwichin aika',
+		'1'		=> '[UTC + 1] Keski-Euroopan aika, Länsi-Afrikan aika',
+		'2'		=> '[UTC + 2] Itä-Euroopan, Keski-Afrikan aika',
+		'3'		=> '[UTC + 3] Moskovan normaaliaika, Itä-Afrikan aika',
+		'3.5'	=> '[UTC + 3:30] Iranin normaaliaika',
+		'4'		=> '[UTC + 4] Persianlahden normaaliaika, Samaran normaaliaika',
+		'4.5'	=> '[UTC + 4:30] Afganistanin aika',
+		'5'		=> '[UTC + 5] Pakistanin normaaliaika, Jekaterinburgin normaaliaika',
+		'5.5'	=> '[UTC + 5:30] Intian normaaliaika, Sri Lankan aika',
+		'5.75'	=> '[UTC + 5:45] Nepalin aika',
+		'6'		=> '[UTC + 6] Bangladeshin aika, Bhutanin aika, Novosibirskin normaaliaika',
+		'6.5'	=> '[UTC + 6:30] Kookossaarten aika, Myanmarin aika',
+		'7'		=> '[UTC + 7] Indokiinan aika, Krasnojarskin normaaliaika',
+		'8'		=> '[UTC + 8] Kiinan normaaliaika, Länsi-Australian normaaliaika, Irkutskin normaaliaika',
+		'8.75'	=> '[UTC + 8:45] Kaakkois-Länsi-Australian normaaliaika',
+		'9'		=> '[UTC + 9] Japanin normaaliaika, Korean normaaliaika, Chitan normaaliaika',
+		'9.5'	=> '[UTC + 9:30] Keski-Australian normaaliaika',
+		'10'	=> '[UTC + 10] Itä-Australian normaaliaika, Vladivostokin normaaliaika',
+		'10.5'	=> '[UTC + 10:30] Lord Howen normaaliaika',
+		'11'	=> '[UTC + 11] Salomonsaarten aika, Magadan Standard Aika',
+		'11.5'	=> '[UTC + 11:30] Norfolkinsaaren aika',
+		'12'	=> '[UTC + 12] Uuden-Seelannin aika, Fidžin aika, Kamtšatkan normaaliaika',
+		'12.75'	=> '[UTC + 12:45] Chathamsaarten aika',
+		'13'	=> '[UTC + 13] Tongan aika, Phoenixsaarten aika',
+		'14'	=> '[UTC + 14] Linesaarten aika',
 	),
 
 	// The value is only an example and will get replaced by the current time on view
