@@ -39,9 +39,9 @@ $lang = array_merge($lang, array(
 	'ACTION'				=> 'Toimenpide',
 	'ACTION_NOTE'			=> 'Toimenpide/Muistiinpanot',
 	'ADD_FEEDBACK'			=> 'Muistiinpanot',
-	'ADD_FEEDBACK_EXPLAIN'	=> 'Voit kirjoittaa muistiinpanoja käyttäjästä käyttämällä oheista lomaketta. Käytä pelkkää tekstiä; HTML, BBCode, jne. Ei ole sallittu.',
+	'ADD_FEEDBACK_EXPLAIN'	=> 'Voit kirjoittaa muistiinpanoja käyttäjästä käyttämällä oheista lomaketta. Käytä pelkkää tekstiä; HTML, BBCode, jne. eivät ole sallittuja.',
 	'ADD_WARNING'			=> 'Lisää varoitus',
-	'ADD_WARNING_EXPLAIN'	=> 'Täytä oheinen lomake lähettääksesi varoituksen käyttäjälle. Käytä pelkkää tekstiä; HTML, BBCode, jne. Ei ole sallittu.',
+	'ADD_WARNING_EXPLAIN'	=> 'Täytä oheinen lomake lähettääksesi varoituksen käyttäjälle. Käytä pelkkää tekstiä; HTML, BBCode, jne. eivät ole sallittuja.',
 	'ALL_ENTRIES'			=> 'Kaikki kirjaukset',
 	'ALL_NOTES_DELETED'		=> 'Tämän käyttäjän muistiinpanot on poistettu',
 	'ALL_REPORTS'			=> 'Kaikki ilmoitukset',
@@ -59,18 +59,18 @@ $lang = array_merge($lang, array(
 	'CANNOT_WARN_SELF'		=> 'Et voi varoittaa itseäsi',
 	'CAN_LEAVE_BLANK'		=> 'Tämän voi jättää tyhjäksi.',
 	'CHANGE_POSTER'			=> 'Vaihda viestin kirjoittaja',
-	'CLOSE_PM_REPORT'		=> 'Sulje YV ilmoitus',
-	'CLOSE_PM_REPORT_CONFIRM'	=> 'Haluatko varmasti sulkea tämän YV ilmoituksen?',
-	'CLOSE_PM_REPORTS'		=> 'Sulje YV ilmoitukset',
-	'CLOSE_PM_REPORTS_CONFIRM'	=> 'Haluatko varmasti sulkea valitsemasi YV ilmoitukset?',
+	'CLOSE_PM_REPORT'		=> 'Sulje yksityisviesti-ilmoitus',
+	'CLOSE_PM_REPORT_CONFIRM'	=> 'Haluatko varmasti sulkea tämän yksityisviesti-ilmoituksen?',
+	'CLOSE_PM_REPORTS'		=> 'Sulje yksityisviesti-ilmoitukset',
+	'CLOSE_PM_REPORTS_CONFIRM'	=> 'Haluatko varmasti sulkea valitsemasi yksityisviesti-ilmoitukset?',
 	'CLOSE_REPORT'			=> 'Sulje ilmoitus',
 	'CLOSE_REPORT_CONFIRM'	=> 'Haluatko varmasti sulkea ilmoituksen?',
 	'CLOSE_REPORTS'			=> 'Sulje ilmoitukset',
 	'CLOSE_REPORTS_CONFIRM'	=> 'Haluatko varmasti sulkea valitsemasi ilmoitukset?',
-	'DELETE_PM_REPORT'			=> 'Poista YV ilmoitus',
-	'DELETE_PM_REPORT_CONFIRM'	=> 'Haluatko varmasti poistaa valitsemasi YV ilmoituksen?',
-	'DELETE_PM_REPORTS'			=> 'Poista YV ilmoitukset',
-	'DELETE_PM_REPORTS_CONFIRM'	=> 'Haluatko varmasti poistaa valitsemasi YV ilmoitukset?',
+	'DELETE_PM_REPORT'			=> 'Poista yksityisviesti-ilmoitus',
+	'DELETE_PM_REPORT_CONFIRM'	=> 'Haluatko varmasti poistaa valitsemasi yksityisviesti-ilmoituksen?',
+	'DELETE_PM_REPORTS'			=> 'Poista yksityisviesti-ilmoitukset',
+	'DELETE_PM_REPORTS_CONFIRM'	=> 'Haluatko varmasti poistaa valitsemasi yksityisviesti-ilmoitukset?',
 
 	'DELETE_POSTS'				=> 'Poista viestit',
 	'DELETE_POSTS_CONFIRM'		=> 'Haluatko varmasti poistaa nämä viestit?',
@@ -93,7 +93,7 @@ $lang = array_merge($lang, array(
 	'DISPLAY_OPTIONS'			=> 'Näytä vaihtoehdot',
 
 	'EMPTY_REPORT'					=> 'Tämä syy vaatii tarkennuksen',
-	'EMPTY_TOPICS_REMOVED_WARNING'	=> 'Huomaa, että yksi tai useampi ketju on poistettu tietokannasta, koska ne tyhjenivät',
+	'EMPTY_TOPICS_REMOVED_WARNING'	=> 'Huomaa, että yksi tai useampi ketju on poistettu tietokannasta, koska ne tyhjenivät.',
 
 	'FEEDBACK'				=> 'Muistiinpano',
 	'FORK'					=> 'Kopioi',
@@ -103,7 +103,7 @@ $lang = array_merge($lang, array(
 	'FORK_TOPICS_CONFIRM'	=> 'Haluatko varmasti kopioida valitut viestiketjut?',
 	'FORUM_DESC'			=> 'Kuvaus',
 	'FORUM_NAME'			=> 'Alueen nimi',
-	'FORUM_NOT_EXIST'		=> 'Alue, jonka valitsit. Ei ole olemassa',
+	'FORUM_NOT_EXIST'		=> 'Valitsemaasi aluetta ei ole olemassa.',
 	'FORUM_NOT_POSTABLE'	=> 'Valitsemallesi alueelle ei voi kirjoittaa uusia viestejä.',
 	'FORUM_STATUS'			=> 'Alueen tilanne',
 	'FORUM_STYLE'			=> 'Alueen tyyli',
@@ -211,7 +211,7 @@ $lang = array_merge($lang, array(
 
 	'MERGE_POSTS_CONFIRM'	=> 'Haluatko varmasti siirtää valitut viestit?',
 	'MERGE_TOPIC_EXPLAIN'	=> 'Käytä oheista lomaketta siirtääksesi valitsemasi viestit toiseen viestiketjuun. Viestit poistetaan tästä viestiketjusta ja yhdistetään toiseen viestiketjuun uusina viesteinä.<br />Anna kohde-viestiketjun ID tai etsi haluamasi viestiketju.',
-	'MERGE_TOPIC_ID'		=> 'Kohde viestiketjun ID',
+	'MERGE_TOPIC_ID'		=> 'Kohde-viestiketjun ID',
 	'MERGE_TOPICS'			=> 'Yhdistä viestiketjut',
 	'MERGE_TOPICS_CONFIRM'	=> 'Haluatko varmasti yhdistää valitut viestiketjut?',
 	'MODERATE_FORUM'		=> 'Hallinnoi aluetta',
