@@ -39,7 +39,7 @@ if (empty($lang) || !is_array($lang))
 $lang = array_merge($lang, array(
 	'TERMS_OF_USE_CONTENT'	=> 'Käyttämällä "%1$s" palvelua (jälkeenpäin "me", "meitä", "meidän", "%1$s", "%2$s"), sitoudut noudattamaan seuraavia ehtoja. Mikäli et hyväksy näitä ehtoja, älä rekisteröidy ja/tai käytä "%1$s"-palvelua. Me voimme muuttaa näitä ehtoja koska tahansa ja teemme parhaamme informoidaksemme sinua. On kuitenkin suositeltavaa lukea nämä ehdot säännöllisesti, koska "%1$s"-palvelun käyttö vaatii että hyväksyt nämä ehdot siinä muodossa, kuin ne on päivitetty tai korjattu.<br />
 	<br />
-	Keskustelufoorumimme käyttää phpBB-ohjelmistoa, (jälkeenpäin "he", "heidät", "heidän", "phpBB-ohjelmisto", "www.phpbb.com", "phpBB Group", "phpBB Tiimit"), joka on julkaistu "<a href="http://www.gnu.org/licenses/gpl.html">General Public License</a>"-lisenssillä (jälkeenpäin "GPL") ja se voidaan ladata osoitteesta <a href="https://www.phpbb.com/">www.phpbb.com</a>. phpBB-ohjelmisto luo vain ympäristön internet-keskustelulle ja GPL-lisenssi kieltää meitä rajoittamasta sivuston sisältöä ja toimintatapaa. Saadaksesi lisätietoa phpBB:stä vieraile osoitteessa: <a href="https://www.phpbb.com/">https://www.phpbb.com/</a>.<br />
+	Keskustelufoorumimme käyttää phpBB-ohjelmistoa, (jälkeenpäin "he", "heidät", "heidän", "phpBB-ohjelmisto", "www.phpbb.com", "phpBB Group", "phpBB Tiimit"), joka on julkaistu "<a href="http://www.gnu.org/licenses/gpl.html">General Public License</a>" -lisenssillä (jälkeenpäin "GPL") ja se voidaan ladata osoitteesta <a href="https://www.phpbb.com/">www.phpbb.com</a>. phpBB-ohjelmisto luo vain ympäristön internet-keskustelulle ja GPL-lisenssi kieltää meitä rajoittamasta sivuston sisältöä ja toimintatapaa. Saadaksesi lisätietoa phpBB:stä vieraile osoitteessa: <a href="https://www.phpbb.com/">https://www.phpbb.com/</a>.<br />
 	<br />
 	Suostut olemaan esittämättä loukkaavaa, vihamielistä, epämoraalista tai muutakaan materiaalia, joka voisi loukata voimassa olevia lakeja oli se sitten omassa maassasi, se maa, johon "%1$s"-palvelin on sijoitettu tai kansainvälisiä lakeja. Toimimalla tätä vastoin voidaan sinut välittömästi ja lopullisesti poistaa järjestelmän käyttäjistä ja tarvittaessa internet-yhteydentarjoajaasi otetaan yhteyttä. Kaikkien viestien IP-osoite tallennetaan näiden ehtojen noudattamisen tarkkailua varten. Hyväksyt, että "%1$s" on oikeus poistaa, muokata, siirtää ja sulkea mikä tahansa keskusteluketju tai viesti niin halutessamme. Suostut myös siihen, että kaikki yllä annettu tieto tallennetaan tietokantaan. Tätä tietoa ei anneta kolmannelle osapuolelle ilman suostumustasi, mutta "%1$s" tai phpBB ei ole vastuussa mahdollisen tietoturvamurron aiheuttamasta tietojen vuodosta ulkopuolisille tahoille.
 	',
@@ -89,7 +89,7 @@ $lang = array_merge($lang, array(
 	'ATTACHMENTS_DELETED'			=> 'Liitetiedostot poistettu',
 	'ATTACHMENT_DELETED'			=> 'Liitetiedosto poistettu',
 	'AVATAR_CATEGORY'				=> 'Kategoria',
-	'AVATAR_EXPLAIN'				=> 'Maksimikoko; leveys %1$d pikseliä, korkeus %2$d pikseliä, tiedoston koko %3$.2f KiB.',
+	'AVATAR_EXPLAIN'				=> 'Enimmäiskoko; leveys %1$d kuvapistettä, korkeus %2$d kuvapistettä, tiedoston koko %3$.2f KiB.',
 	'AVATAR_FEATURES_DISABLED'		=> 'Avatar-toiminnot ovat tällä hetkellä pois käytöstä.',
 	'AVATAR_GALLERY'				=> 'Paikallinen galleria',
 	'AVATAR_GENERAL_UPLOAD_ERROR'	=> 'En voinut siirtää avataria %s -hakemistoon',
@@ -102,13 +102,13 @@ $lang = array_merge($lang, array(
 	'BIRTHDAY'					=> 'Syntymäpäivä',
 	'BIRTHDAY_EXPLAIN'			=> 'Saat oman ikäsi näkyviin antamalla syntymävuotesi.',
 	'BOARD_DATE_FORMAT'			=> 'Ajan näyttö',
-	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Käytettävä syntaksi vastaa PHP:n <a href="http://www.php.net/date" onclick="this.target=\'_blank\';" title="Avautuu uuteen ikkunaan">date()</a> funktiota',
+	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Käytettävä syntaksi vastaa PHP:n <a href="http://www.php.net/date" onclick="this.target=\'_blank\';" title="Avautuu uuteen ikkunaan">date()</a>-funktiota',
 	'BOARD_DST'					=> 'Kesäaika käytössä',
 	'BOARD_LANGUAGE'			=> 'Käytettävä kieli',
 	'BOARD_STYLE'				=> 'Käytettävä tyyli',
 	'BOARD_TIMEZONE'			=> 'Aikavyöhyke',
 	'BOOKMARKS'					=> 'Kirjanmerkit',
-	'BOOKMARKS_EXPLAIN'			=> 'Voit lisätä kirjanmerkin myöhempää tarkastelua varten. Voit poistaa kirjanmerkin laittamalla rastin sen vieressä olevaan ruutuun ja painamalla <em>Poista valitut kirjanmerkit</em> nappulaa.',
+	'BOOKMARKS_EXPLAIN'			=> 'Voit lisätä kirjanmerkin myöhempää tarkastelua varten. Voit poistaa kirjanmerkin laittamalla rastin sen vieressä olevaan ruutuun ja painamalla <em>Poista valitut kirjanmerkit</em> -nappulaa.',
 	'BOOKMARKS_DISABLED'		=> 'Kirjanmerkit ovat poissa käytöstä tällä keskustelufoorumilla',
 	'BOOKMARKS_REMOVED'			=> 'Kirjanmerkit poistettu',
 
@@ -119,8 +119,8 @@ $lang = array_merge($lang, array(
 	'CANNOT_REMOVE_FOLDER'		=> 'Tätä kansiota ei voi poistaa.',
 	'CHANGE_DEFAULT_GROUP'		=> 'Vaihda oletusryhmää',
 	'CHANGE_PASSWORD'			=> 'Vaihda salasanaa',
-    'CLICK_GOTO_FOLDER'         => '%1$sMene “%3$s” kansioon%2$s',
-	'CLICK_RETURN_FOLDER'		=> '%1$sPalaa "%3$s" kansioon%2$s',
+    'CLICK_GOTO_FOLDER'         => '%1$sMene “%3$s” -kansioon%2$s',
+	'CLICK_RETURN_FOLDER'		=> '%1$sPalaa "%3$s" -kansioon%2$s',
 	'CONFIRMATION'				=> 'Vahvistuskoodi',
 	'CONFIRM_CHANGES'			=> 'Varmista muutokset',	
 	'CONFIRM_EMAIL'				=> 'Varmista sähköpostiosoite',
@@ -133,7 +133,7 @@ $lang = array_merge($lang, array(
 	'CONFIRM_PASSWORD_EXPLAIN'	=> 'Salasana täytyy varmistaa vain, jos vaihdat sen.',
 	'COPPA_BIRTHDAY'			=> 'Kerro meille koska olet syntynyt ennen kuin jatkat rekisteröitymistä',
 	'COPPA_COMPLIANCE'			=> 'COPPA-vahvistus',
-	'COPPA_EXPLAIN'				=> 'Huomaa. Käyttäjätunnuksesi luodaan, kun lähetät tämän lomakkeen. Tunnuksiasi ei kuitenkaan aktivoida ennen kuin vanhempasi tai huoltajasi antaa siihen suostumuksensa. Sinulle tulee tarvittava lomake toimintaohjeineen sähköpostiin.',
+	'COPPA_EXPLAIN'				=> 'Huomaa, että käyttäjätunnuksesi luodaan, kun lähetät tämän lomakkeen. Tunnuksiasi ei kuitenkaan aktivoida ennen kuin vanhempasi tai huoltajasi antaa siihen suostumuksensa. Sinulle tulee tarvittava lomake toimintaohjeineen sähköpostiin.',
 	'CREATE_FOLDER'				=> 'Lisää kansio...',
 	'CURRENT_IMAGE'				=> 'Nykyinen kuva',
 	'CURRENT_PASSWORD'			=> 'Nykyinen salasana',
@@ -146,10 +146,10 @@ $lang = array_merge($lang, array(
 	'DEFAULT_ACTION'			=> 'Oletustoimenpide',
 	'DEFAULT_ACTION_EXPLAIN'	=> 'Tämä toiminto suoritetaan, jos mikään ylläolevista vaihtoehdoista ei päde',
 	'DEFAULT_ADD_SIG'			=> 'Lisää allekirjoitus automaattisesti',
-	'DEFAULT_BBCODE'			=> 'BBcode on aina päällä',
+	'DEFAULT_BBCODE'			=> 'BBCode on aina päällä',
 	'DEFAULT_NOTIFY'			=> 'Ilmoita aina vastauksista',
 	'DEFAULT_SMILIES'			=> 'Hymiöt ovat aina päällä',
-	'DEFINED_RULES'				=> 'määritä säännöt',
+	'DEFINED_RULES'				=> 'Määritetyt säännöt',
 	'DELETED_TOPIC'				=> 'Viestiketju on poistettu',
 	'DELETE_ATTACHMENT'			=> 'Poista liitetiedosto',
 	'DELETE_ATTACHMENTS'		=> 'Poista liitetiedostot',
@@ -168,30 +168,30 @@ $lang = array_merge($lang, array(
 	'DEMOTE_SELECTED'			=> 'Alenna valituista',
 	'DISABLE_CENSORS'			=> 'Käytä sanojen sensurointia',
 	'DISPLAY_GALLERY'			=> 'Näytä galleria',
-	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Antamallasi sähköpostin toimialueella ei ole kelvollista MX tietuetta.',
+	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Antamallasi sähköpostin toimialueella ei ole kelvollista MX-tietuetta.',
 	'DOWNLOADS'					=> 'Lataukset',
 	'DRAFTS_DELETED'			=> 'Kaikki valitut luonnokset on poistettu.',
 	'DRAFTS_EXPLAIN'			=> 'Täällä voit katsoa, muokata ja poistaa valitsemiasi luonnoksia.',
 	'DRAFT_UPDATED'				=> 'Luonnos on päivitetty.',
 
-	'EDIT_DRAFT_EXPLAIN'		=> 'Täällä voit muokata luonnoksiasi. luonnoksissa ei ole mukana äänestystä tai liitetiedostoja.',
+	'EDIT_DRAFT_EXPLAIN'		=> 'Täällä voit muokata luonnoksiasi. Luonnoksissa ei ole mukana äänestystä tai liitetiedostoja.',
 	'EMAIL_BANNED_EMAIL'		=> 'Antamasi sähköpostiosoitteen käyttäminen ei ole sallittu.',
 	'EMAIL_REMIND'				=> 'Tämän täytyy olla sama sähköpostiosoite, jonka annoit rekisteröityessäsi.',
 	'EMAIL_TAKEN_EMAIL'			=> 'Antamasi sähköpostiosoite on jo käytössä.',
 	'EMPTY_DRAFT'				=> 'Sinun täyty antaa viesti lähettääksesi muutokset',
 	'EMPTY_DRAFT_TITLE'			=> 'Sinun täytyy antaa luonnokselle otsikko',
-	'EXPORT_AS_XML'				=> 'Vie XML tiedostoon',
-	'EXPORT_AS_CSV'				=> 'Vie CSV tiedostoon',
-	'EXPORT_AS_CSV_EXCEL'		=> 'Vie CSV (Excel) tiedostoon',
-	'EXPORT_AS_TXT'				=> 'Vie TXT tiedostoon',
-	'EXPORT_AS_MSG'				=> 'Vie MSG tiedostoon',
+	'EXPORT_AS_XML'				=> 'Vie XML-tiedostoon',
+	'EXPORT_AS_CSV'				=> 'Vie CSV-tiedostoon',
+	'EXPORT_AS_CSV_EXCEL'		=> 'Vie CSV (Excel) -tiedostoon',
+	'EXPORT_AS_TXT'				=> 'Vie TXT-tiedostoon',
+	'EXPORT_AS_MSG'				=> 'Vie MSG-tiedostoon',
 	'EXPORT_FOLDER'				=> 'Vie valitussa muodossa',
 
 	'FIELD_REQUIRED'					=> 'Kenttä “%s” täytyy täyttää.',
 	'FIELD_TOO_SHORT'					=> 'Kenttä "%1$s" on liian lyhyt. Vaaditaan vähintään %2$d merkkiä.',
-	'FIELD_TOO_LONG'					=> 'Kenttä "%1$s" on liian pitkä. Merkkien maksimimäärä on %2$d kpl.',
-	'FIELD_TOO_SMALL'					=> '"%1$s" arvo on liian matala. Minimi arvo on %2$d .',
-	'FIELD_TOO_LARGE'					=> '"%1$s" arvo on liian suuri. Maksimi arvo on %2$d .',
+	'FIELD_TOO_LONG'					=> 'Kenttä "%1$s" on liian pitkä. Merkkien enimmäismäärä on %2$d kpl.',
+	'FIELD_TOO_SMALL'					=> '"%1$s" arvo on liian matala. Vähimmäisarvo on %2$d .',
+	'FIELD_TOO_LARGE'					=> '"%1$s" arvo on liian suuri. Ensimmäisarvo on %2$d .',
 	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain numerot ovat sallittuja.',
 	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain kirjoitusmerkit ovat sallittuja.',
 	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain kirjaimet, numerot, välilyönnit tai -+_[] merkit ovat sallittuja.',
@@ -252,7 +252,7 @@ $lang = array_merge($lang, array(
 
 	'MARK_IMPORTANT'				=> 'Merkitse tärkeäksi',
 	'MARKED_MESSAGE'				=> 'Merkitty viesti',
-	'MAX_FOLDER_REACHED'			=> 'Olet lisännyt maksimimäärän kansioita',
+	'MAX_FOLDER_REACHED'			=> 'Olet lisännyt enimmäismäärän kansioita',
 	'MESSAGE_BY_AUTHOR'				=> 'Lähettäjä:',
 	'MESSAGE_COLOURS'				=> 'Viestin värit',
 	'MESSAGE_DELETED'				=> 'Viesti poistettu',
@@ -292,7 +292,7 @@ $lang = array_merge($lang, array(
 	'NOT_ADDED_FOES_FRIENDS'		=> 'Et voi lisätä käyttäjiä vihamiehiksi, jos he ovat merkitty ystäviksi.',
  	'NOT_ADDED_FOES_SELF'			=> 'Et voi lisätä itseäsi vihamieheksi.',
 	'NOT_AGREE'						=> 'En hyväksy',
-	'NOT_ENOUGH_SPACE_FOLDER'		=> 'Kohdekansio “%s” on täynnä. valitsemaasi toimenpidettä ei voitu suorittaa.',
+	'NOT_ENOUGH_SPACE_FOLDER'		=> 'Kohdekansio “%s” on täynnä. Valitsemaasi toimenpidettä ei voitu suorittaa.',
 	'NOT_MOVED_MESSAGE'				=> 'Sinulla on 1 kpl yksityisviestejä pidätettynä, koska kansiosi on täynnä.',
 	'NOT_MOVED_MESSAGES'			=> 'Sinulla on %d kappaletta yksityisviestejä pidätettynä, koska kansiosi on täynnä.',
 	'NO_ACTION_MODE'				=> 'Viestin toimintoa ei ole määritelty',
@@ -305,7 +305,7 @@ $lang = array_merge($lang, array(
 	'NO_AUTH_GROUP_MESSAGE'			=> 'Et voi lähettää yksityisviestejä käyttäjäryhmille.',
     'NO_AUTH_PASSWORD_REMINDER'     => 'Et voi pyytää uutta salasanaa.',
     'NO_AUTH_READ_HOLD_MESSAGE'     => 'Et voi lukea pidätettyjä yksityisviestejä.',
-	'NO_AUTH_READ_MESSAGE'			=> 'Et voi lukea ykasityisviestejä.',
+	'NO_AUTH_READ_MESSAGE'			=> 'Et voi lukea yksityisviestejä.',
 	'NO_AUTH_READ_REMOVED_MESSAGE'	=> 'Et voi lukea tätä yksitysiviestiä, koska lähettäjä on poistanut sen.',
 	'NO_AUTH_SEND_MESSAGE'			=> 'Et voi lähettää yksityisviestejä.',
 	'NO_AUTH_SIGNATURE'				=> 'Et voi lisätä allekirjoitusta',
@@ -339,8 +339,8 @@ $lang = array_merge($lang, array(
 	'PASS_TYPE_CASE_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä. Siinä tulee sekoittaa ISOJA ja pieniä kirjaimia',
 	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä. Siinä tulee olla ISOJA ja pieniä kirjaimia, sekä numeroita ja symboleita',
 	'PASSWORD'					=> 'Salasana',
-	'PASSWORD_ACTIVATED'		=> 'uusi salasanasi on aktivoitu',
-	'PASSWORD_UPDATED'			=> 'salasanasi on lähetetty tiedoissasi olevaan sähköpostiosoitteeseen.',
+	'PASSWORD_ACTIVATED'		=> 'Uusi salasanasi on aktivoitu.',
+	'PASSWORD_UPDATED'			=> 'Salasanasi on lähetetty tiedoissasi olevaan sähköpostiosoitteeseen.',
 	'PERMISSIONS_RESTORED'		=> 'Alkuperäiset oikeudet palautettu.',
 	'PERMISSIONS_TRANSFERRED'	=> 'Oikeudet on siirretty käyttäjältä <strong>%s</strong> ja voit nyt selata keskustelufoorumia tämän käyttäjän oikeuksilla.<br />Huomaa, että ylläpitäjän oikeuksia ei ole siirretty. Voit vaihtaa omat oikeudet takaisin koska haluat.',
 	'PM_DISABLED'				=> 'Yksityisviestit ovat poissa käytöstä.',
@@ -370,7 +370,7 @@ $lang = array_merge($lang, array(
 	'RECIPIENT'							=> 'Vastaanottaja',
 	'RECIPIENTS'						=> 'Vastaanottajat',
 	'REGISTRATION'						=> 'Rekisteröityminen',
-	'RELEASE_MESSAGES'					=> '%sVapauta kaikki pidätetyt viestit%s... Viestit toimitetaan oikeisiin kansiooihin, mikäli tilaa on vapaana.',
+	'RELEASE_MESSAGES'					=> '%sVapauta kaikki pidätetyt viestit%s... Viestit toimitetaan oikeisiin kansioihin, mikäli tilaa on vapaana.',
 	'REMOVE_ADDRESS'					=> 'Poista osoite',
 	'REMOVE_SELECTED_BOOKMARKS'			=> 'Poista valitut kirjanmerkit',
 	'REMOVE_SELECTED_BOOKMARKS_CONFIRM' => 'Haluatko varmasti poistaa valitut kirjanmerkit?',
@@ -388,7 +388,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'Sääntö lisätty',
 	'RULE_ALREADY_DEFINED'				=> 'Tämä sääntö on jo määritelty',
 	'RULE_DELETED'						=> 'sääntö poistettu',
-	'RULE_LIMIT_REACHED'				=> 'Et voi luoda uutta YV-sääntöä. Sinulla on jo maksimimäärä sääntöjä käytössä.',
+	'RULE_LIMIT_REACHED'				=> 'Et voi luoda uutta YV-sääntöä. Sinulla on jo enimmäismäärä sääntöjä käytössä.',
 	'RULE_NOT_DEFINED'					=> 'Sääntöä ei ole määritelty oikein',
 	'RULE_REMOVED_MESSAGE'				=> 'Yksityisviestien suodattimet ovat poistaneet yhden viestin.',
 	'RULE_REMOVED_MESSAGES'				=> 'Yksityisviestien suodattimet ovat poistaneet %d viestiä.',
@@ -421,9 +421,9 @@ $lang = array_merge($lang, array(
 	'UCP_ATTACHMENTS'			=> 'Liitetiedostot',
 	'UCP_COPPA_BEFORE'			=> 'Ennen %s',
 	'UCP_COPPA_ON_AFTER'		=> 'Samaan aikaan, tai jälkeen %s',
-	'UCP_EMAIL_ACTIVATE'		=> 'Huomaa, että antamasi sähköpostiosoitteen tulee olla toimiva, jotta tunnuksesi voidaan aktivoida. Saat sähköpostin antamaasi osoitteeseen, jossa on mukana aktivointilinkki tunnuksellesi. Sinun täytyy klikata tuota linkkiä ennen kuin voit kirjautua sisään.',
-	'UCP_ICQ'					=> 'ICQ numero',
-	'UCP_JABBER'				=> 'Jabber osoite',
+	'UCP_EMAIL_ACTIVATE'		=> 'Huomaa, että antamasi sähköpostiosoitteen tulee olla toimiva, jotta tunnuksesi voidaan aktivoida. Saat sähköpostin antamaasi osoitteeseen, jossa on mukana aktivointilinkki tunnuksellesi. Sinun täytyy napsauttaa tuota linkkiä ennen kuin voit kirjautua sisään.',
+	'UCP_ICQ'					=> 'ICQ-numero',
+	'UCP_JABBER'				=> 'Jabber-osoite',
 
 	'UCP_MAIN'					=> 'Yleiset',
 	'UCP_MAIN_ATTACHMENTS'		=> 'Hallinnoi liitetiedostoja',
@@ -473,9 +473,9 @@ $lang = array_merge($lang, array(
 	'UPLOAD_AVATAR_FILE'			=> 'Siirrä omalta koneeltasi',
 	'UPLOAD_AVATAR_URL'				=> 'Kopioi osoitteesta',
 	'UPLOAD_AVATAR_URL_EXPLAIN'		=> 'Anna avatar-kuvan osoite. Kuva kopioidaan tämän sivuston palvelimelle.',
-	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Käyttäjätunnuksessa täytyy olla vähintään %1$d merkkiä ja maksimissaan %2$d merkkiä. Voit käyttää vain kirjaimia ja numeroita',
+	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Käyttäjätunnuksessa täytyy olla vähintään %1$d merkkiä ja enintään %2$d merkkiä. Voit käyttää vain kirjaimia ja numeroita',
 	'USERNAME_ALPHA_SPACERS_EXPLAIN'=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä tulee olla kirjaimia, numeroita ,välilyöntejä tai -+_[] merkkejä.',
-	'USERNAME_ASCII_EXPLAIN'		=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää ainoastaan ASCII merkkejä, eli ei symboleja',
+	'USERNAME_ASCII_EXPLAIN'		=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää ainoastaan ASCII-merkkejä, eli ei symboleja',
 	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää ainoastaan kirjaimia ja numeroita',
 	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää kirjaimia, numeroita, välilyöntiä tai -+_[] merkkejä.',
 	'USERNAME_CHARS_ANY_EXPLAIN'	=> 'Pituuden täytyy olla %1$d ja %2$d merkin väliltä.',
@@ -485,7 +485,7 @@ $lang = array_merge($lang, array(
 
 	'VIEW_AVATARS'				=> 'Näytä avatarit',
 	'VIEW_EDIT'					=> 'Katso/muokkaa',
-	'VIEW_FLASH'				=> 'Näytä Flash animaatiot',
+	'VIEW_FLASH'				=> 'Näytä Flash-animaatiot',
 	'VIEW_IMAGES'				=> 'Näytä viesteihin liitetyt kuvat',
 	'VIEW_NEXT_HISTORY'			=> 'Seuraava yksityisviesti taaksepäin',
 	'VIEW_NEXT_PM'				=> 'Seuraava yksityisviesti',
@@ -504,7 +504,7 @@ $lang = array_merge($lang, array(
 	'VIEW_POSTS_DIR'			=> 'Viestien suunta',
 	'VIEW_POSTS_KEY'			=> 'Lajittele viestit',
 
-	'WATCHED_EXPLAIN'			=> 'Alapuolella olevat alueet ja viestiketjut ovat seurannassa. Saat ilmoituksen aina uusista viesteistä. Voit lopettaa seurannan valitsemalla haluamasi ketjun tai alueen ja klikkaamalla <em>Lopeta seuranta</em> nappulaa.',
+	'WATCHED_EXPLAIN'			=> 'Alapuolella olevat alueet ja viestiketjut ovat seurannassa. Saat ilmoituksen aina uusista viesteistä. Voit lopettaa seurannan valitsemalla haluamasi ketjun tai alueen ja napsauttamalla <em>Lopeta seuranta</em> -nappulaa.',
 	'WATCHED_FORUMS'			=> 'Seuratut alueet',
 	'WATCHED_TOPICS'			=> 'Seuratut viestiketjut',
 	'WRONG_ACTIVATION'			=> 'Antamasi aktivointiavain ei täsmää tietokannassa olevan kanssa',
@@ -547,7 +547,7 @@ $lang = array_merge($lang, array(
 	),
 
 
-	'GROUPS_EXPLAIN'	=> 'Käyttäjäryhmät auttavat ylläpitoa hallinnoimaan käyttäjiä. Sinut laitetaan rekisteröityessäsi johonkin ryhmään ja tämä ryhmä on oletusryhmäsi. Tämä ryhmä määrittelee näkyvyytesi toisille käyttäjille, kuten simerkiksi käyttäjätunnuksen värin, avatarin, arvon, jne... Mikäli ylläpito on sallinut, voit vaihtaa oletusryhmääsi. Sinut voidaan myös liittää toisiin ryhmiin. Jotkut käyttäjäryhmät sallivat sinun nähdä piilotettuja alueita tai antavat lisää oikeuksia tietyille alueille.',
+	'GROUPS_EXPLAIN'	=> 'Käyttäjäryhmät auttavat ylläpitoa hallinnoimaan käyttäjiä. Sinut laitetaan rekisteröityessäsi johonkin ryhmään ja tämä ryhmä on oletusryhmäsi. Tämä ryhmä määrittelee näkyvyytesi toisille käyttäjille, kuten simerkiksi käyttäjätunnuksen värin, avatarin, arvon, jne. Mikäli ylläpito on sallinut, voit vaihtaa oletusryhmääsi. Sinut voidaan myös liittää toisiin ryhmiin. Jotkut käyttäjäryhmät sallivat sinun nähdä piilotettuja alueita tai antavat lisää oikeuksia tietyille alueille.',
 	'GROUP_LEADER'		=> 'valvojana',
 	'GROUP_MEMBER'		=> 'Jäsenenä',
 	'GROUP_PENDING'		=> 'Odottavat jäsenyydet',
